(function(la,ma,na,oa,B,pa,r,qa,s,w,x,ra,sa,C,ta,D,ua,N,va,O,E,ea,wa,fa,xa,ya,za,Aa,Ba,Ca,b,Da,Ea,P,Fa,Ga,Ha,Ia,Ja,Ka,La,Ma,Na,Oa,Pa,Qa,Ra,Sa,Ta,Ua,Va,Wa,Xa,Ya,Za,$a,ab,bb,j,n){var h=Jmol.__$;if(!h.ui)try{var l=h,R=function(a,c){var e,b,d,g=a.nodeName.toLowerCase();return"area"===g?(e=a.parentNode,b=e.name,!a.href||!b||"map"!==e.nodeName.toLowerCase()?!1:(d=l("img[usemap=#"+b+"]")[0],!!d&&Q(d))):(/input|select|textarea|button|object/.test(g)?!a.disabled:"a"===g?a.href||c:c)&&Q(a)},Q=function(a){return l.expr.filters.visible(a)&&
!l(a).parents().andSelf().filter(function(){return"hidden"===l.css(this,"visibility")}).length},ga=0,ha=/^ui-id-\d+$/;l.ui=l.ui||{};if(!l.ui.version){l.extend(l.ui,{version:"1.9.2",keyCode:{BACKSPACE:8,COMMA:188,DELETE:46,DOWN:40,END:35,ENTER:13,ESCAPE:27,HOME:36,LEFT:37,NUMPAD_ADD:107,NUMPAD_DECIMAL:110,NUMPAD_DIVIDE:111,NUMPAD_ENTER:108,NUMPAD_MULTIPLY:106,NUMPAD_SUBTRACT:109,PAGE_DOWN:34,PAGE_UP:33,PERIOD:190,RIGHT:39,SPACE:32,TAB:9,UP:38}});l.fn.extend({_focus:l.fn.focus,focus:function(a,c){return"number"==
typeof a?this.each(function(){var e=this;setTimeout(function(){l(e).focus();c&&c.call(e)},a)}):this._focus.apply(this,arguments)},scrollParent:function(){var a;return l.ui.ie&&/(static|relative)/.test(this.css("position"))||/absolute/.test(this.css("position"))?a=this.parents().filter(function(){return/(relative|absolute|fixed)/.test(l.css(this,"position"))&&/(auto|scroll)/.test(l.css(this,"overflow")+l.css(this,"overflow-y")+l.css(this,"overflow-x"))}).eq(0):a=this.parents().filter(function(){return/(auto|scroll)/.test(l.css(this,
"overflow")+l.css(this,"overflow-y")+l.css(this,"overflow-x"))}).eq(0),/fixed/.test(this.css("position"))||!a.length?l(document):a},zIndex:function(a){if(void 0!==a)return this.css("zIndex",a);if(this.length){a=l(this[0]);for(var c;a.length&&a[0]!==document;){c=a.css("position");if("absolute"===c||"relative"===c||"fixed"===c)if(c=parseInt(a.css("zIndex"),10),!isNaN(c)&&0!==c)return c;a=a.parent()}}return 0},uniqueId:function(){return this.each(function(){this.id||(this.id="ui-id-"+ ++ga)})},removeUniqueId:function(){return this.each(function(){ha.test(this.id)&&
l(this).removeAttr("id")})}});l.extend(l.expr[":"],{data:l.expr.createPseudo?l.expr.createPseudo(function(a){return function(c){return!!l.data(c,a)}}):function(a,c,e){return!!l.data(a,e[3])},focusable:function(a){return R(a,!isNaN(l.attr(a,"tabindex")))},tabbable:function(a){var c=l.attr(a,"tabindex"),e=isNaN(c);return(e||0<=c)&&R(a,!e)}});l(function(){var a=document.body,c=a.appendChild(c=document.createElement("div"));c.offsetHeight;l.extend(c.style,{minHeight:"100px",height:"auto",padding:0,borderWidth:0});
l.support.minHeight=100===c.offsetHeight;l.support.selectstart="onselectstart"in c;a.removeChild(c).style.display="none"});l("<a>").outerWidth(1).jquery||l.each(["Width","Height"],function(a,c){function e(a,c,e,d){return l.each(b,function(){c-=parseFloat(l.css(a,"padding"+this))||0;e&&(c-=parseFloat(l.css(a,"border"+this+"Width"))||0);d&&(c-=parseFloat(l.css(a,"margin"+this))||0)}),c}var b="Width"===c?["Left","Right"]:["Top","Bottom"],d=c.toLowerCase(),g={innerWidth:l.fn.innerWidth,innerHeight:l.fn.innerHeight,
outerWidth:l.fn.outerWidth,outerHeight:l.fn.outerHeight};l.fn["inner"+c]=function(a){return void 0===a?g["inner"+c].call(this):this.each(function(){l(this).css(d,e(this,a)+"px")})};l.fn["outer"+c]=function(a,b){return"number"!=typeof a?g["outer"+c].call(this,a):this.each(function(){l(this).css(d,e(this,a,!0,b)+"px")})}});if(l("<a>").data("a-b","a").removeData("a-b").data("a-b")){var T=l.fn.removeData;l.fn.removeData=function(a){return arguments.length?T.call(this,l.camelCase(a)):T.call(this)}}var U=
/msie ([\w.]+)/.exec(navigator.userAgent.toLowerCase())||[];l.ui.ie=U.length?!0:!1;l.ui.ie6=6===parseFloat(U[1],10);l.fn.extend({disableSelection:function(){return this.bind((l.support.selectstart?"selectstart":"mousedown")+".ui-disableSelection",function(a){a.preventDefault()})},enableSelection:function(){return this.unbind(".ui-disableSelection")}});l.extend(l.ui,{plugin:{add:function(a,c,e){var b;a=l.ui[a].prototype;for(b in e)a.plugins[b]=a.plugins[b]||[],a.plugins[b].push([c,e[b]])},call:function(a,
c,e){var b=a.plugins[c];if(b&&a.element[0].parentNode&&11!==a.element[0].parentNode.nodeType)for(c=0;c<b.length;c++)a.options[b[c][0]]&&b[c][1].apply(a.element,e)}},contains:l.contains,hasScroll:function(a,c){if("hidden"===l(a).css("overflow"))return!1;var e=c&&"left"===c?"scrollLeft":"scrollTop";return 0<a[e]?!0:(a[e]=1,a[e]=0,!1)},isOverAxis:function(a,c,e){return a>c&&a<c+e},isOver:function(a,c,e,b,d,g){return l.ui.isOverAxis(a,e,d)&&l.ui.isOverAxis(c,b,g)}})}}catch(cb){Zystem.out.println("coremenu failed to load jQuery.ui.core -- jQuery version conflict?")}if(!h.ui.widget)try{var k=
h,ia=0,V=Array.prototype.slice,ja=k.cleanData;k.cleanData=function(a){for(var c=0,e;null!=(e=a[c]);c++)try{k(e).triggerHandler("remove")}catch(b){}ja(a)};k.widget=function(a,c,e){var b,d,g,m,h=a.split(".")[0];a=a.split(".")[1];b=h+"-"+a;e||(e=c,c=k.Widget);k.expr[":"][b.toLowerCase()]=function(a){return!!k.data(a,b)};k[h]=k[h]||{};d=k[h][a];g=k[h][a]=function(a,c){if(!this._createWidget)return new g(a,c);arguments.length&&this._createWidget(a,c)};k.extend(g,d,{version:e.version,_proto:k.extend({},
e),_childConstructors:[]});m=new c;m.options=k.widget.extend({},m.options);k.each(e,function(a,b){if(k.isFunction(b)){var f=function(){return c.prototype[a].apply(this,arguments)},d=function(e){return c.prototype[a].apply(this,e)};e[a]=function(){var a=this._super,c=this._superApply,e;return this._super=f,this._superApply=d,e=b.apply(this,arguments),this._super=a,this._superApply=c,e}}});g.prototype=k.widget.extend(m,{widgetEventPrefix:d?m.widgetEventPrefix:a},e,{constructor:g,namespace:h,widgetName:a,
widgetBaseClass:b,widgetFullName:b});d?(k.each(d._childConstructors,function(a,c){var e=c.prototype;k.widget(e.namespace+"."+e.widgetName,g,c._proto)}),delete d._childConstructors):c._childConstructors.push(g);k.widget.bridge(a,g)};k.widget.extend=function(a){for(var c=V.call(arguments,1),e=0,b=c.length,d,g;e<b;e++)for(d in c[e])g=c[e][d],c[e].hasOwnProperty(d)&&void 0!==g&&(k.isPlainObject(g)?a[d]=k.isPlainObject(a[d])?k.widget.extend({},a[d],g):k.widget.extend({},g):a[d]=g);return a};k.widget.bridge=
function(a,c){var e=c.prototype.widgetFullName||a;k.fn[a]=function(b){var d="string"==typeof b,g=V.call(arguments,1),m=this;return b=!d&&g.length?k.widget.extend.apply(null,[b].concat(g)):b,d?this.each(function(){var c,d=k.data(this,e);if(!d)return k.error("cannot call methods on "+a+" prior to initialization; attempted to call method '"+b+"'");if(!k.isFunction(d[b])||"_"===b.charAt(0))return k.error("no such method '"+b+"' for "+a+" widget instance");c=d[b].apply(d,g);if(c!==d&&void 0!==c)return m=
c&&c.jquery?m.pushStack(c.get()):c,!1}):this.each(function(){var a=k.data(this,e);a?a.option(b||{})._init():k.data(this,e,new c(b,this))}),m}};k.Widget=function(){};k.Widget._childConstructors=[];k.Widget.prototype={widgetName:"widget",widgetEventPrefix:"",defaultElement:"<div>",options:{disabled:!1,create:null},_createWidget:function(a,c){c=k(c||this.defaultElement||this)[0];this.element=k(c);this.uuid=ia++;this.eventNamespace="."+this.widgetName+this.uuid;this.options=k.widget.extend({},this.options,
this._getCreateOptions(),a);this.bindings=k();this.hoverable=k();this.focusable=k();c!==this&&(k.data(c,this.widgetName,this),k.data(c,this.widgetFullName,this),this._on(!0,this.element,{remove:function(a){a.target===c&&this.destroy()}}),this.document=k(c.style?c.ownerDocument:c.document||c),this.window=k(this.document[0].defaultView||this.document[0].parentWindow));this._create();this._trigger("create",null,this._getCreateEventData());this._init()},_getCreateOptions:k.noop,_getCreateEventData:k.noop,
_create:k.noop,_init:k.noop,destroy:function(){this._destroy();this.element.unbind(this.eventNamespace).removeData(this.widgetName).removeData(this.widgetFullName).removeData(k.camelCase(this.widgetFullName));this.widget().unbind(this.eventNamespace).removeAttr("aria-disabled").removeClass(this.widgetFullName+"-disabled ui-state-disabled");this.bindings.unbind(this.eventNamespace);this.hoverable.removeClass("ui-state-hover");this.focusable.removeClass("ui-state-focus")},_destroy:k.noop,widget:function(){return this.element},
option:function(a,c){var e=a,b,d,g;if(0===arguments.length)return k.widget.extend({},this.options);if("string"==typeof a)if(e={},b=a.split("."),a=b.shift(),b.length){d=e[a]=k.widget.extend({},this.options[a]);for(g=0;g<b.length-1;g++)d[b[g]]=d[b[g]]||{},d=d[b[g]];a=b.pop();if(void 0===c)return void 0===d[a]?null:d[a];d[a]=c}else{if(void 0===c)return void 0===this.options[a]?null:this.options[a];e[a]=c}return this._setOptions(e),this},_setOptions:function(a){for(var c in a)this._setOption(c,a[c]);
return this},_setOption:function(a,c){return this.options[a]=c,"disabled"===a&&(this.widget().toggleClass(this.widgetFullName+"-disabled ui-state-disabled",!!c).attr("aria-disabled",c),this.hoverable.removeClass("ui-state-hover"),this.focusable.removeClass("ui-state-focus")),this},enable:function(){return this._setOption("disabled",!1)},disable:function(){return this._setOption("disabled",!0)},_on:function(a,c,e){var b,d=this;"boolean"!=typeof a&&(e=c,c=a,a=!1);e?(c=b=k(c),this.bindings=this.bindings.add(c)):
(e=c,c=this.element,b=this.widget());k.each(e,function(e,m){function h(){if(a||!(!0===d.options.disabled||k(this).hasClass("ui-state-disabled")))return("string"==typeof m?d[m]:m).apply(d,arguments)}"string"!=typeof m&&(h.guid=m.guid=m.guid||h.guid||k.guid++);var j=e.match(/^(\w+)\s*(.*)$/),l=j[1]+d.eventNamespace;(j=j[2])?b.delegate(j,l,h):c.bind(l,h)})},_off:function(a,c){c=(c||"").split(" ").join(this.eventNamespace+" ")+this.eventNamespace;a.unbind(c).undelegate(c)},_delay:function(a,c){var e=
this;return setTimeout(function(){return("string"==typeof a?e[a]:a).apply(e,arguments)},c||0)},_hoverable:function(a){this.hoverable=this.hoverable.add(a);this._on(a,{mouseenter:function(a){k(a.currentTarget).addClass("ui-state-hover")},mouseleave:function(a){k(a.currentTarget).removeClass("ui-state-hover")}})},_focusable:function(a){this.focusable=this.focusable.add(a);this._on(a,{focusin:function(a){k(a.currentTarget).addClass("ui-state-focus")},focusout:function(a){k(a.currentTarget).removeClass("ui-state-focus")}})},
_trigger:function(a,c,e){var b,d=this.options[a];e=e||{};c=k.Event(c);c.type=(a===this.widgetEventPrefix?a:this.widgetEventPrefix+a).toLowerCase();c.target=this.element[0];if(a=c.originalEvent)for(b in a)b in c||(c[b]=a[b]);return this.element.trigger(c,e),!(k.isFunction(d)&&!1===d.apply(this.element[0],[c].concat(e))||c.isDefaultPrevented())}};k.each({show:"fadeIn",hide:"fadeOut"},function(a,c){k.Widget.prototype["_"+a]=function(e,b,d){"string"==typeof b&&(b={effect:b});var g,m=b?!0===b||"number"==
typeof b?c:b.effect||c:a;b=b||{};"number"==typeof b&&(b={duration:b});g=!k.isEmptyObject(b);b.complete=d;b.delay&&e.delay(b.delay);g&&k.effects&&(k.effects.effect[m]||!1!==k.uiBackCompat&&k.effects[m])?e[a](b):m!==a&&e[m]?e[m](b.duration,b.easing,d):e.queue(function(c){k(this)[a]();d&&d.call(e[0]);c()})}});!1!==k.uiBackCompat&&(k.Widget.prototype._getCreateOptions=function(){return k.metadata&&k.metadata.get(this.element[0])[this.widgetName]})}catch(db){Zystem.out.println("coremenu failed to load jQuery.ui.widget -- jQuery version conflict?")}if(!h.ui.mouse)try{var F=
!1;h(document).mouseup(function(){F=!1});h.widget("ui.mouse",{version:"1.9.2",options:{cancel:"input,textarea,button,select,option",distance:1,delay:0},_mouseInit:function(){var a=this;this.element.bind("mousedown."+this.widgetName,function(c){return a._mouseDown(c)}).bind("click."+this.widgetName,function(c){if(!0===h.data(c.target,a.widgetName+".preventClickEvent"))return h.removeData(c.target,a.widgetName+".preventClickEvent"),c.stopImmediatePropagation(),!1});this.started=!1},_mouseDestroy:function(){this.element.unbind("."+
this.widgetName);this._mouseMoveDelegate&&h(document).unbind("mousemove."+this.widgetName,this._mouseMoveDelegate).unbind("mouseup."+this.widgetName,this._mouseUpDelegate)},_mouseDown:function(a){if(!F){this._mouseStarted&&this._mouseUp(a);this._mouseDownEvent=a;var c=this,e=1===a.which,b="string"==typeof this.options.cancel&&a.target.nodeName?h(a.target).closest(this.options.cancel).length:!1;if(!e||b||!this._mouseCapture(a))return!0;(this.mouseDelayMet=!this.options.delay)||(this._mouseDelayTimer=
setTimeout(function(){c.mouseDelayMet=!0},this.options.delay));return this._mouseDistanceMet(a)&&this._mouseDelayMet(a)&&(this._mouseStarted=!1!==this._mouseStart(a),!this._mouseStarted)?(a.preventDefault(),!0):(!0===h.data(a.target,this.widgetName+".preventClickEvent")&&h.removeData(a.target,this.widgetName+".preventClickEvent"),this._mouseMoveDelegate=function(a){return c._mouseMove(a)},this._mouseUpDelegate=function(a){return c._mouseUp(a)},h(document).bind("mousemove."+this.widgetName,this._mouseMoveDelegate).bind("mouseup."+
this.widgetName,this._mouseUpDelegate),a.preventDefault(),F=!0,!0)}},_mouseMove:function(a){return!h.ui.ie||9<=document.documentMode||a.button?this._mouseStarted?(this._mouseDrag(a),a.preventDefault()):(this._mouseDistanceMet(a)&&this._mouseDelayMet(a)&&(this._mouseStarted=!1!==this._mouseStart(this._mouseDownEvent,a),this._mouseStarted?this._mouseDrag(a):this._mouseUp(a)),!this._mouseStarted):this._mouseUp(a)},_mouseUp:function(a){return h(document).unbind("mousemove."+this.widgetName,this._mouseMoveDelegate).unbind("mouseup."+
this.widgetName,this._mouseUpDelegate),this._mouseStarted&&(this._mouseStarted=!1,a.target===this._mouseDownEvent.target&&h.data(a.target,this.widgetName+".preventClickEvent",!0),this._mouseStop(a)),!1},_mouseDistanceMet:function(a){return Math.max(Math.abs(this._mouseDownEvent.pageX-a.pageX),Math.abs(this._mouseDownEvent.pageY-a.pageY))>=this.options.distance},_mouseDelayMet:function(){return this.mouseDelayMet},_mouseStart:function(){},_mouseDrag:function(){},_mouseStop:function(){},_mouseCapture:function(){return!0}})}catch(eb){Zystem.out.println("coremenu failed to load jQuery.ui.mouse -- jQuery version conflict?")}if(!h.ui.position)try{var X=
function(a,c,e){return[parseInt(a[0],10)*(W.test(a[0])?c/100:1),parseInt(a[1],10)*(W.test(a[1])?e/100:1)]};h.ui=h.ui||{};var G,A=Math.max,t=Math.abs,Y=Math.round,Z=/left|center|right/,$=/top|center|bottom/,aa=/[\+\-]\d+%?/,ba=/^\w+/,W=/%$/,ka=h.fn.position;h.position={scrollbarWidth:function(){if(void 0!==G)return G;var a,c,e=h("<div style='display:block;width:50px;height:50px;overflow:hidden;'><div style='height:100px;width:auto;'></div></div>"),b=e.children()[0];return h("body").append(e),a=b.offsetWidth,
e.css("overflow","scroll"),c=b.offsetWidth,a===c&&(c=e[0].clientWidth),e.remove(),G=a-c},getScrollInfo:function(a){var c=a.isWindow?"":a.element.css("overflow-x"),e=a.isWindow?"":a.element.css("overflow-y"),e="scroll"===e||"auto"===e&&a.height<a.element[0].scrollHeight;return{width:"scroll"===c||"auto"===c&&a.width<a.element[0].scrollWidth?h.position.scrollbarWidth():0,height:e?h.position.scrollbarWidth():0}},getWithinInfo:function(a){a=h(a||window);var c=h.isWindow(a[0]);return{element:a,isWindow:c,
offset:a.offset()||{left:0,top:0},scrollLeft:a.scrollLeft(),scrollTop:a.scrollTop(),width:c?a.width():a.outerWidth(),height:c?a.height():a.outerHeight()}}};h.fn.position=function(a){if(!a||!a.of)return ka.apply(this,arguments);a=h.extend({},a);var c,e,b,d,g,m=h(a.of),j=h.position.getWithinInfo(a.within),k=h.position.getScrollInfo(j),l=m[0],n=(a.collision||"flip").split(" "),p={};return 9===l.nodeType?(e=m.width(),b=m.height(),d={top:0,left:0}):h.isWindow(l)?(e=m.width(),b=m.height(),d={top:m.scrollTop(),
left:m.scrollLeft()}):l.preventDefault?(a.at="left top",e=b=0,d={top:l.pageY,left:l.pageX}):(e=m.outerWidth(),b=m.outerHeight(),d=m.offset()),g=h.extend({},d),h.each(["my","at"],function(){var c=(a[this]||"").split(" "),e,b;1===c.length&&(c=Z.test(c[0])?c.concat(["center"]):$.test(c[0])?["center"].concat(c):["center","center"]);c[0]=Z.test(c[0])?c[0]:"center";c[1]=$.test(c[1])?c[1]:"center";e=aa.exec(c[0]);b=aa.exec(c[1]);p[this]=[e?e[0]:0,b?b[0]:0];a[this]=[ba.exec(c[0])[0],ba.exec(c[1])[0]]}),1===
n.length&&(n[1]=n[0]),"right"===a.at[0]?g.left+=e:"center"===a.at[0]&&(g.left+=e/2),"bottom"===a.at[1]?g.top+=b:"center"===a.at[1]&&(g.top+=b/2),c=X(p.at,e,b),g.left+=c[0],g.top+=c[1],this.each(function(){var l,S,r=h(this),s=r.outerWidth(),y=r.outerHeight(),u=parseInt(h.css(this,"marginLeft"),10)||0,w=parseInt(h.css(this,"marginTop"),10)||0,x=s+u+(parseInt(h.css(this,"marginRight"),10)||0)+k.width,z=y+w+(parseInt(h.css(this,"marginBottom"),10)||0)+k.height,q=h.extend({},g),v=X(p.my,r.outerWidth(),
r.outerHeight());"right"===a.my[0]?q.left-=s:"center"===a.my[0]&&(q.left-=s/2);"bottom"===a.my[1]?q.top-=y:"center"===a.my[1]&&(q.top-=y/2);q.left+=v[0];q.top+=v[1];h.support.offsetFractions||(q.left=Y(q.left),q.top=Y(q.top));l={marginLeft:u,marginTop:w};h.each(["left","top"],function(d,g){h.ui.position[n[d]]&&h.ui.position[n[d]][g](q,{targetWidth:e,targetHeight:b,elemWidth:s,elemHeight:y,collisionPosition:l,collisionWidth:x,collisionHeight:z,offset:[c[0]+v[0],c[1]+v[1]],my:a.my,at:a.at,within:j,
elem:r})});h.fn.bgiframe&&r.bgiframe();a.using&&(S=function(c){var g=d.left-q.left,h=g+e-s,j=d.top-q.top,k=j+b-y,l={target:{element:m,left:d.left,top:d.top,width:e,height:b},element:{element:r,left:q.left,top:q.top,width:s,height:y},horizontal:0>h?"left":0<g?"right":"center",vertical:0>k?"top":0<j?"bottom":"middle"};e<s&&t(g+h)<e&&(l.horizontal="center");b<y&&t(j+k)<b&&(l.vertical="middle");A(t(g),t(h))>A(t(j),t(k))?l.important="horizontal":l.important="vertical";a.using.call(this,c,l)});r.offset(h.extend(q,
{using:S}))})};h.ui.position={fit:{left:function(a,c){var e=c.within,b=e.isWindow?e.scrollLeft:e.offset.left,e=e.width,d=a.left-c.collisionPosition.marginLeft,g=b-d,m=d+c.collisionWidth-e-b,h;c.collisionWidth>e?0<g&&0>=m?(h=a.left+g+c.collisionWidth-e-b,a.left+=g-h):0<m&&0>=g?a.left=b:g>m?a.left=b+e-c.collisionWidth:a.left=b:0<g?a.left+=g:0<m?a.left-=m:a.left=A(a.left-d,a.left)},top:function(a,c){var b=c.within,b=b.isWindow?b.scrollTop:b.offset.top,f=c.within.height,d=a.top-c.collisionPosition.marginTop,
g=b-d,m=d+c.collisionHeight-f-b,h;c.collisionHeight>f?0<g&&0>=m?(h=a.top+g+c.collisionHeight-f-b,a.top+=g-h):0<m&&0>=g?a.top=b:g>m?a.top=b+f-c.collisionHeight:a.top=b:0<g?a.top+=g:0<m?a.top-=m:a.top=A(a.top-d,a.top)}},flip:{left:function(a,c){var b=c.within,f=b.offset.left+b.scrollLeft,d=b.width,g=b.isWindow?b.scrollLeft:b.offset.left,m=a.left-c.collisionPosition.marginLeft,b=m-g,h=m+c.collisionWidth-d-g,m="left"===c.my[0]?-c.elemWidth:"right"===c.my[0]?c.elemWidth:0,j="left"===c.at[0]?c.targetWidth:
"right"===c.at[0]?-c.targetWidth:0,k=-2*c.offset[0];if(0>b){if(f=a.left+m+j+k+c.collisionWidth-d-f,0>f||f<t(b))a.left+=m+j+k}else if(0<h&&(f=a.left-c.collisionPosition.marginLeft+m+j+k-g,0<f||t(f)<h))a.left+=m+j+k},top:function(a,c){var b=c.within,f=b.offset.top+b.scrollTop,d=b.height,b=b.isWindow?b.scrollTop:b.offset.top,g=a.top-c.collisionPosition.marginTop,m=g-b,g=g+c.collisionHeight-d-b,h="top"===c.my[1]?-c.elemHeight:"bottom"===c.my[1]?c.elemHeight:0,j="top"===c.at[1]?c.targetHeight:"bottom"===
c.at[1]?-c.targetHeight:0,k=-2*c.offset[1],l,n;0>m?(n=a.top+h+j+k+c.collisionHeight-d-f,a.top+h+j+k>m&&(0>n||n<t(m))&&(a.top+=h+j+k)):0<g&&(l=a.top-c.collisionPosition.marginTop+h+j+k-b,a.top+h+j+k>g&&(0<l||t(l)<g)&&(a.top+=h+j+k))}},flipfit:{left:function(){h.ui.position.flip.left.apply(this,arguments);h.ui.position.fit.left.apply(this,arguments)},top:function(){h.ui.position.flip.top.apply(this,arguments);h.ui.position.fit.top.apply(this,arguments)}}};var u,z,v,H,I,K=document.getElementsByTagName("body")[0],
L=document.createElement("div");u=document.createElement(K?"div":"body");v={visibility:"hidden",width:0,height:0,border:0,margin:0,background:"none"};K&&h.extend(v,{position:"absolute",left:"-1000px",top:"-1000px"});for(I in v)u.style[I]=v[I];u.appendChild(L);z=K||document.documentElement;z.insertBefore(u,z.firstChild);L.style.cssText="position: absolute; left: 10.7432222px;";H=h(L).offset().left;h.support.offsetFractions=10<H&&11>H;u.innerHTML="";z.removeChild(u);if(!1!==h.uiBackCompat){var ca=h.fn.position;
h.fn.position=function(a){if(!a||!a.offset)return ca.call(this,a);var c=a.offset.split(" "),b=a.at.split(" ");return 1===c.length&&(c[1]=c[0]),/^\d/.test(c[0])&&(c[0]="+"+c[0]),/^\d/.test(c[1])&&(c[1]="+"+c[1]),1===b.length&&(/left|center|right/.test(b[0])?b[1]="center":(b[1]=b[0],b[0]="center")),ca.call(this,h.extend(a,{at:b[0]+c[0]+" "+b[1]+c[1],offset:void 0}))}}}catch(fb){Zystem.out.println("coremenu failed to load jQuery.ui.position -- jQuery version conflict?")}if(!h.ui.menu)try{var M=!1;h.widget("ui.menu",
{version:"1.9.2",defaultElement:"<ul>",delay:300,options:{icons:{submenu:"ui-icon-carat-1-e"},menus:"ul",position:{my:"left top",at:"right top"},role:"menu",blur:null,focus:null,select:null},_create:function(){this.activeMenu=this.element;this.element.uniqueId().addClass("ui-menu ui-widget ui-widget-content ui-corner-all").toggleClass("ui-menu-icons",!!this.element.find(".ui-icon").length).attr({role:this.options.role,tabIndex:0}).bind("click"+this.eventNamespace,h.proxy(function(a){this.options.disabled&&
a.preventDefault()},this));this.options.disabled&&this.element.addClass("ui-state-disabled").attr("aria-disabled","true");this._on({"mousedown .ui-menu-item > a":function(a){a.preventDefault()},"click .ui-state-disabled > a":function(a){a.preventDefault()},"click .ui-menu-item:has(a)":function(a){var c=h(a.target).closest(".ui-menu-item");!M&&c.not(".ui-state-disabled").length&&(M=!0,this.select(a),c.has(".ui-menu").length?this.expand(a):this.element.is(":focus")||(this.element.trigger("focus",[!0]),
this.active&&1===this.active.parents(".ui-menu").length&&clearTimeout(this.timer)))},"mouseenter .ui-menu-item":function(a){var c=h(a.currentTarget);c.siblings().children(".ui-state-active").removeClass("ui-state-active");this.focus(a,c)},mouseleave:"collapseAll","mouseleave .ui-menu":"collapseAll",focus:function(a,c){var b=this.active||this.element.children(".ui-menu-item").eq(0);c||this.focus(a,b)},blur:function(a){this._delay(function(){h.contains(this.element[0],this.document[0].activeElement)||
this.collapseAll(a)})},keydown:"_keydown"});this.refresh();this._on(this.document,{click:function(a){h(a.target).closest(".ui-menu").length||this.collapseAll(a);M=!1}})},_destroy:function(){this.element.removeAttr("aria-activedescendant").find(".ui-menu").andSelf().removeClass("ui-menu ui-widget ui-widget-content ui-corner-all ui-menu-icons").removeAttr("role").removeAttr("tabIndex").removeAttr("aria-labelledby").removeAttr("aria-expanded").removeAttr("aria-hidden").removeAttr("aria-disabled").removeUniqueId().show();
this.element.find(".ui-menu-item").removeClass("ui-menu-item").removeAttr("role").removeAttr("aria-disabled").children("a").removeUniqueId().removeClass("ui-corner-all ui-state-hover").removeAttr("tabIndex").removeAttr("role").removeAttr("aria-haspopup").children().each(function(){var a=h(this);a.data("ui-menu-submenu-carat")&&a.remove()});this.element.find(".ui-menu-divider").removeClass("ui-menu-divider ui-widget-content")},_keydown:function(a){function c(a){return a.replace(/[\-\[\]{}()*+?.,\\\^$|#\s]/g,
"\\$&")}var b,f,d,g,m=!0;switch(a.keyCode){case h.ui.keyCode.PAGE_UP:this.previousPage(a);break;case h.ui.keyCode.PAGE_DOWN:this.nextPage(a);break;case h.ui.keyCode.HOME:this._move("first","first",a);break;case h.ui.keyCode.END:this._move("last","last",a);break;case h.ui.keyCode.UP:this.previous(a);break;case h.ui.keyCode.DOWN:this.next(a);break;case h.ui.keyCode.LEFT:this.collapse(a);break;case h.ui.keyCode.RIGHT:this.active&&!this.active.is(".ui-state-disabled")&&this.expand(a);break;case h.ui.keyCode.ENTER:case h.ui.keyCode.SPACE:this._activate(a);
break;case h.ui.keyCode.ESCAPE:this.collapse(a);break;default:m=!1,b=this.previousFilter||"",f=String.fromCharCode(a.keyCode),d=!1,clearTimeout(this.filterTimer),f===b?d=!0:f=b+f,g=RegExp("^"+c(f),"i"),b=this.activeMenu.children(".ui-menu-item").filter(function(){return g.test(h(this).children("a").text())}),b=d&&-1!==b.index(this.active.next())?this.active.nextAll(".ui-menu-item"):b,b.length||(f=String.fromCharCode(a.keyCode),g=RegExp("^"+c(f),"i"),b=this.activeMenu.children(".ui-menu-item").filter(function(){return g.test(h(this).children("a").text())})),
b.length?(this.focus(a,b),1<b.length?(this.previousFilter=f,this.filterTimer=this._delay(function(){delete this.previousFilter},1E3)):delete this.previousFilter):delete this.previousFilter}m&&a.preventDefault()},_activate:function(a){this.active.is(".ui-state-disabled")||(this.active.children("a[aria-haspopup='true']").length?this.expand(a):this.select(a))},refresh:function(){var a,c=this.options.icons.submenu;a=this.element.find(this.options.menus);a.filter(":not(.ui-menu)").addClass("ui-menu ui-widget ui-widget-content ui-corner-all").hide().attr({role:this.options.role,
"aria-hidden":"true","aria-expanded":"false"}).each(function(){var a=h(this),b=a.prev("a"),d=h("<span>").addClass("ui-menu-icon ui-icon "+c).data("ui-menu-submenu-carat",!0);b.attr("aria-haspopup","true").prepend(d);a.attr("aria-labelledby",b.attr("id"))});a=a.add(this.element);a.children(":not(.ui-menu-item):has(a)").addClass("ui-menu-item").attr("role","presentation").children("a").uniqueId().addClass("ui-corner-all").attr({tabIndex:-1,role:this._itemRole()});a.children(":not(.ui-menu-item)").each(function(){var a=
h(this);/[^\-+\ufffdG\ufffd\ufffdG\ufffd\ufffd+\ufffdG\ufffd\ufffdG\ufffd\ufffd\s]/.test(a.text())||a.addClass("ui-widget-content ui-menu-divider")});a.children(".ui-state-disabled").attr("aria-disabled","true");this.active&&!h.contains(this.element[0],this.active[0])&&this.blur()},_itemRole:function(){return{menu:"menuitem",listbox:"option"}[this.options.role]},focus:function(a,c){var b;this.blur(a,a&&"focus"===a.type);this._scrollIntoView(c);this.active=c.first();b=this.active.children("a").addClass("ui-state-focus");
this.options.role&&this.element.attr("aria-activedescendant",b.attr("id"));this.active.parent().closest(".ui-menu-item").children("a:first").addClass("ui-state-active");a&&"keydown"===a.type?this._close():this.timer=this._delay(function(){this._close()},this.delay);b=c.children(".ui-menu");b.length&&/^mouse/.test(a.type)&&this._startOpening(b);this.activeMenu=c.parent();this._trigger("focus",a,{item:c})},_scrollIntoView:function(a){var c,b,f,d,g,m;this._hasScroll()&&(c=parseFloat(h.css(this.activeMenu[0],
"borderTopWidth"))||0,b=parseFloat(h.css(this.activeMenu[0],"paddingTop"))||0,f=a.offset().top-this.activeMenu.offset().top-c-b,d=this.activeMenu.scrollTop(),g=this.activeMenu.height(),m=a.height(),0>f?this.activeMenu.scrollTop(d+f):f+m>g&&this.activeMenu.scrollTop(d+f-g+m))},blur:function(a,c){c||clearTimeout(this.timer);this.active&&(this.active.children("a").removeClass("ui-state-focus"),this.active=null,this._trigger("blur",a,{item:this.active}))},_startOpening:function(a){a.hasClass("ui-state-disabled")||
(clearTimeout(this.timer),"true"===a.attr("aria-hidden")&&(this.timer=this._delay(function(){this._close();this._open(a)},this.delay)))},_open:function(a){var c=h.extend({of:this.active},this.options.position);clearTimeout(this.timer);this.element.find(".ui-menu").not(a.parents(".ui-menu")).hide().attr("aria-hidden","true");a.show().removeAttr("aria-hidden").attr("aria-expanded","true").position(c)},collapseAll:function(a,c){clearTimeout(this.timer);this.timer=this._delay(function(){var b=c?this.element:
h(a&&a.target).closest(this.element.find(".ui-menu"));b.length||(b=this.element);this._close(b);this.blur(a);this.activeMenu=b},this.delay)},_close:function(a){a||(a=this.active?this.active.parent():this.element);a.find(".ui-menu").hide().attr("aria-hidden","true").attr("aria-expanded","false").end().find("a.ui-state-active").removeClass("ui-state-active")},collapse:function(a){var c=this.active&&this.active.parent().closest(".ui-menu-item",this.element);c&&c.length&&(this._close(),this.focus(a,c))},
expand:function(a){var c=this.active&&this.active.children(".ui-menu ").children(".ui-menu-item").first();c&&c.length&&(this._open(c.parent()),this._delay(function(){this.focus(a,c)}))},next:function(a){this._move("next","first",a)},previous:function(a){this._move("prev","last",a)},isFirstItem:function(){return this.active&&!this.active.prevAll(".ui-menu-item").length},isLastItem:function(){return this.active&&!this.active.nextAll(".ui-menu-item").length},_move:function(a,c,b){var f;this.active&&
("first"===a||"last"===a?f=this.active["first"===a?"prevAll":"nextAll"](".ui-menu-item").eq(-1):f=this.active[a+"All"](".ui-menu-item").eq(0));if(!f||!f.length||!this.active)f=this.activeMenu.children(".ui-menu-item")[c]();this.focus(b,f)},nextPage:function(a){var c,b,f;this.active?this.isLastItem()||(this._hasScroll()?(b=this.active.offset().top,f=this.element.height(),this.active.nextAll(".ui-menu-item").each(function(){return c=h(this),0>c.offset().top-b-f}),this.focus(a,c)):this.focus(a,this.activeMenu.children(".ui-menu-item")[this.active?
"last":"first"]())):this.next(a)},previousPage:function(a){var c,b,f;this.active?this.isFirstItem()||(this._hasScroll()?(b=this.active.offset().top,f=this.element.height(),this.active.prevAll(".ui-menu-item").each(function(){return c=h(this),0<c.offset().top-b+f}),this.focus(a,c)):this.focus(a,this.activeMenu.children(".ui-menu-item").first())):this.next(a)},_hasScroll:function(){return this.element.outerHeight()<this.element.prop("scrollHeight")},select:function(a){this.active=this.active||h(a.target).closest(".ui-menu-item");
var c={item:this.active};this.active.has(".ui-menu").length||this.collapseAll(a,!0);this._trigger("select",a,c)}})}catch(gb){Zystem.out.println("JSmolMenu failed to load jQuery.ui.menu -- jQuery version conflict?")}var p=Jmol.Swing;if(!p.menuInitialized){p.menuCounter=0;p.menuInitialized=1;p.__getMenuStyle=function(a){return"\t.jmolPopupMenu{font-family:Arial,sans-serif;font-size:11px;position:absolute;z-index:"+Jmol._getZ(a,"menu")+'}\t.jmolPopupMenu,.jmolPopupMenu .ui-corner-all{border-radius:5px}\t.jmolPopupMenu,.jmolPopupMenu .ui-widget-content{border:1px solid #a6c9e2;background-color:#fcfdfd;color:#222}\t.jmolPopupMenu a{color:#222;font-size:10px;}\t.jmolPopupMenu input[type="checkbox"]{vertical-align:middle;}\t.jmolPopupMenu,.jmolPopupMenu .ui-menu{list-style:none;padding:2px;margin:0;display:block;outline:none;box-shadow:1px 1px 5px rgba(50,50,50,0.75)}\t.jmolPopupMenu .ui-menu{margin-top:-3px;position:absolute}\t.jmolPopupMenu .ui-menu-item{cursor:pointer;margin:0 2ex 0 0;padding:0;width:100%}\t.jmolPopupMenu .ui-menu-divider{margin:3px 1px;height:0;font-size:0;line-height:0;border-width:1px 0 0 0}\t.jmolPopupMenu .ui-menu-item a{text-decoration:none;display:block;padding:0.05em 0.4em;white-space:nowrap;border:1px solid transparent}\t.jmolPopupMenu .ui-menu-icons{position:relative}\t.jmolPopupMenu .ui-menu-icons .ui-menu-item a{position:relative;padding-left:2em}\t.jmolPopupMenu .ui-icon{display:block;text-indent:-99999px;overflow:hidden;background-repeat:no-repeat;position:absolute;top:.2em;left:.2em}\t.jmolPopupMenu .ui-menu-icon{position:static;float:right}\t.jmolPopupMenu .ui-icon-carat-1-e{min-width:2ex;text-align:right;background-image:none;background-position:0 0}\t.jmolPopupMenu .ui-icon-carat-1-e:after{content:"\\25B8"}\t.jmolPopupMenu .ui-state-default{border:1px solid #c5dbec;background:#dfeffc;color:#2e6e9e}\t.jmolPopupMenu .ui-state-default a{color:#2e6e9e;text-decoration:none}\t.jmolPopupMenu .ui-state-hover,.jmolPopupMenu .ui-state-focus{border:1px solid #79b7e7;background:#d0e5f5;color:#1d5987}\t.jmolPopupMenu .ui-state-hover a{color:#1d5987;text-decoration:none}\t.jmolPopupMenu .ui-state-active{border:1px solid #79b7e7;background:#f5f8f9;color:#e17009}\t.jmolPopupMenu .ui-state-active a{color:#e17009;text-decoration:none}\t.jmolPopupMenu .ui-state-highlight{border:1px solid #fad42e;background:#fbec88;color:#363636}\t.jmolPopupMenu .ui-state-highlight a{color:#363636}\t.jmolPopupMenu .ui-state-disabled *{background:grey!important,color:#d6d6d6!important;font-weight:normal;cursor:default}\t.jmolPopupMenu .ui-state-disabled a:hover{background-color:transparent!important;border-color:transparent!important}\t.jmolPopupMenu .ui-state-disabled .ui-icon{filter:Alpha(Opacity=35)}'};
p.setMenu=function(a){p.__getMenuStyle&&Jmol.$after("head","<style>"+p.__getMenuStyle(a.applet)+"</style>");p.__getStyle=null;a.tainted=!0;a.popupMenu=a;a.id="top";a.id=p.getMenuID(a);a.applet._menus||(a.applet._menus={});a.applet._menus[a.name]=a;Jmol.$after("body",'<ul id="'+a.id+'" class="jmolPopupMenu"></ul>');a.setContainer(Jmol.$("#"+a.id))};p.showMenu=function(a,c,b){Jmol._showMenuCallback&&Jmol._showMenuCallback(a,c,b);a.tainted&&(a.container.html(a.toHTML()),a.tainted=!1,p.bindMenuActionCommands(a,
!0));a.setPosition();a.container.hide().menu().menu("refresh").show();a._visible=!0;a.timestamp=Zystem.currentTimeMillis();a.dragBind(!0);a.container.unbind("clickoutjsmol");Jmol._persistentMenu||a.container.bind("clickoutjsmol mousemoveoutjsmol",function(){1E3<Zystem.currentTimeMillis()-a.timestamp&&p.hideMenu(a)});a.container.bind("contextmenu",function(){return!1})};p.disposeMenu=function(a){Jmol._persistentMenu||(p.hideMenu(a),p.bindMenuActionCommands(a,!1),delete a.applet._menus[a.name])};p.initMenuItem=
function(a){a.applet=a.popupMenu.applet;a.id=p.getMenuID(a);a.icon&&(a.icon='<img src="'+a.applet._j2sPath+"/"+a.icon+'" style="max-height: 20px;" />')};p.getMenuID=function(a){var c=a.popupMenu;return c.applet._id+"_"+c.name+"_"+a.id+"_"+ ++p.menuCounter};p.hideMenu=function(a){a._visible&&(a.dragBind(!1),a.container.hide(),a._visible=a.isDragging=!1)};var da=function(a,c){setTimeout(function(){p.hideMenus(a.applet);c()},500)};p.bindMenuActionCommands=function(a,c){for(var b=a.getComponentCount(),
f=0;f<b;f++)p.bindMenuActionCommands(a.getComponent(f),c);Jmol.$documentOff("click mouseup mouseover mousedown touchstart touchend mouseenter mouseleave",a.id);c&&(Jmol.$documentOn("click",a.id,function(){var c=""+a.name,c=0>c.indexOf("Persist")||0<=c.indexOf("!Persist");a.itemListener?(a.selected=2==a.btnType?Jmol.$prop(a.id+"-cb","checked"):!0,c&&da(a,function(){a.itemListener.itemStateChanged({getSource:function(){return a}})})):a.actionListener&&c&&da(a,function(){a.actionListener.actionPerformed({getSource:function(){return a},
getActionCommand:function(){return a.actionCommand}})})}),Jmol.$documentOn("mouseup mouseover mousedown touchstart touchend mouseenter mouseleave",a.id,function(c){a.mouseListener&&a.mouseListener.handleEvent&&a.mouseListener.handleEvent({jqevent:c,getID:function(){return c.type},getSource:function(){return a}})}))}}r("J.popup");s(["J.api.GenericMenuInterface","java.util.Hashtable","JU.Lst"],"J.popup.GenericPopup",["java.util.StringTokenizer","JU.PT","$.SB","JU.Logger"],function(){c$=x(function(){this.strMenuStructure=
this.helper=null;this.isWebGL=this.isSigned=this.isApplet=this.isJS=this.allowSignedFeatures=!1;this.thisy=this.thisx=0;this.isTainted=!0;this.SignedOnly=this.htMenus=this.currentMenuItemId=this.buttonGroup=this.htCheckbox=this.thisPopup=this.popupMenu=this.menuName=null;this.updatingForShow=!1;w(this,arguments)},J.popup,"GenericPopup",null,J.api.GenericMenuInterface);E(c$,function(){this.htCheckbox=new java.util.Hashtable;this.htMenus=new java.util.Hashtable;this.SignedOnly=new JU.Lst});j(c$,"appCheckItem",
function(){},"~S,J.api.SC");j(c$,"appCheckSpecialMenu",function(){},"~S,J.api.SC,~S");j(c$,"initSwing",function(a,c,b,f,d,g){this.isJS=f;this.isApplet=null!=b;this.isSigned=d;this.isWebGL=g;this.allowSignedFeatures=!this.isApplet||d;this.menuName=a;this.thisPopup=this.popupMenu=this.helper.menuCreatePopup(a,b);this.htMenus.put(a,this.popupMenu);this.addMenuItems("",a,this.popupMenu,c)},"~S,J.popup.PopupResource,~O,~B,~B,~B");j(c$,"addMenuItems",function(a,c,b,f){a=a+"."+c;var d=f.getStructure(c);
JU.Logger.debugging&&JU.Logger.debug(a+" --- "+d);if(null==d)this.menuCreateItem(b,"#"+c,"","");else{c=new java.util.StringTokenizer(d);for(var g;0<=d.indexOf("@");){for(d="";c.hasMoreTokens();)d+=" "+((g=c.nextToken()).startsWith("@")?f.getStructure(g):g);d=d.substring(1);c=new java.util.StringTokenizer(d)}for(;c.hasMoreTokens();)if(g=c.nextToken(),this.checkKey(g))if("-".equals(g))this.menuAddSeparator(b),this.helper.menuAddButtonGroup(null);else{var d=f.getWord(g),m=null,m="",h=!1,d=this.appFixLabel(null==
d?g:d);if(!d.equals("null")){if(0<=g.indexOf("Menu")){0>g.indexOf("more")&&this.helper.menuAddButtonGroup(null);var j=this.menuNewSubMenu(d,a+"."+g);this.menuAddSubMenu(b,j);this.addMenu(a,g,j,d,f);m=j}else if(g.endsWith("Checkbox")||(h=g.endsWith("CB")||g.endsWith("RD"))){m=f.getStructure(g);j=g.substring(0,g.length-(!h?8:2));h=h&&g.endsWith("RD");if(null==m||0==m.length&&!h)m="set "+j+" T/F";m=this.menuCreateCheckboxItem(b,d,j+":"+m,a+"."+g,!1,h);this.rememberCheckbox(j,m);h&&this.helper.menuAddButtonGroup(m)}else m=
f.getStructure(g),null==m&&(m=g),m=this.menuCreateItem(b,d,m,a+"."+g);this.htMenus.put(g,m);g.startsWith("SIGNED")&&(this.SignedOnly.addLast(m),this.allowSignedFeatures||this.menuEnable(m,!1));this.appCheckItem(g,m)}}}},"~S,~S,J.api.SC,J.popup.PopupResource");j(c$,"addMenu",function(a,c,b,f,d){0>c.indexOf("Computed")&&this.addMenuItems(a,c,b,d);this.appCheckSpecialMenu(c,b,f)},"~S,~S,J.api.SC,~S,J.popup.PopupResource");j(c$,"updateSignedAppletItems",function(){for(var a=this.SignedOnly.size();0<=
--a;)this.menuEnable(this.SignedOnly.get(a),this.allowSignedFeatures)});j(c$,"checkKey",function(a){return 0>a.indexOf(this.isApplet?"JAVA":"APPLET")&&(!this.isWebGL||0>a.indexOf("NOGL"))},"~S");j(c$,"rememberCheckbox",function(a,c){this.htCheckbox.put(a+"::"+this.htCheckbox.size(),c)},"~S,J.api.SC");j(c$,"updateButton",function(a,c,e){c=b(-1,[c]);var f=this.getEntryIcon(c);c=c[0];a.init(c,f,e,this.thisPopup);this.isTainted=!0},"J.api.SC,~S,~S");j(c$,"getEntryIcon",function(a){var c=a[0];if(!c.startsWith("<"))return null;
var b=c.indexOf(">");a[0]=c.substring(b+1);a=c.substring(1,b);return this.getImageIcon(a)},"~A");j(c$,"addMenuItem",function(a,c){return this.menuCreateItem(a,c,"",null)},"J.api.SC,~S");j(c$,"menuSetLabel",function(a,c){null!=a&&(a.setText(c),this.isTainted=!0)},"J.api.SC,~S");j(c$,"menuClickCallback",function(a,c){this.doMenuClickCallback(a,c)},"J.api.SC,~S");j(c$,"doMenuClickCallback",function(a,c){this.appRestorePopupMenu();if(!(null==c||0==c.length))if(c.equals("MAIN"))this.show(this.thisx,this.thisy,
!0);else{var b=this.menuGetId(a);null!=b&&(c=this.getScriptForCallback(a,b,c),this.currentMenuItemId=b);null!=c&&this.appRunScript(c)}},"J.api.SC,~S");j(c$,"menuCheckBoxCallback",function(a){this.doMenuCheckBoxCallback(a)},"J.api.SC");j(c$,"doMenuCheckBoxCallback",function(a){this.appRestorePopupMenu();var c=a.isSelected(),b=a.getActionCommand();this.runCheckBoxScript(a,b,c);this.appUpdateSpecialCheckBoxValue(a,b,c);this.isTainted=!0;a=this.menuGetId(a);null!=a&&(this.currentMenuItemId=a)},"J.api.SC");
j(c$,"runCheckBoxScript",function(a,c,b){if(a.isEnabled()){if(0>c.indexOf("##")){var f=c.indexOf(":");if(0>f){JU.Logger.error("check box "+a+" IS "+c);return}var d=c.substring(0,f);if(this.appRunSpecialCheckBox(a,d,c,b))return;c=c.substring(f+1);if(0<=(f=c.indexOf("|")))c=(b?c.substring(0,f):c.substring(f+1)).trim();c=JU.PT.rep(c,"T/F",b?" TRUE":" FALSE")}this.appRunScript(c)}},"J.api.SC,~S,~B");j(c$,"menuCreateItem",function(a,c,b,f){var d=this.helper.getMenuItem(c);d.addActionListener(this.helper);
return this.newMenuItem(d,a,c,b,f)},"J.api.SC,~S,~S,~S");j(c$,"menuCreateCheckboxItem",function(a,c,b,f,d,g){g=g?this.helper.getRadio(c):this.helper.getCheckBox(c);g.setSelected(d);g.addItemListener(this.helper);return this.newMenuItem(g,a,c,b,f)},"J.api.SC,~S,~S,~S,~B,~B");j(c$,"menuAddSeparator",function(a){a.add(this.helper.getMenuItem(null));this.isTainted=!0},"J.api.SC");j(c$,"menuNewSubMenu",function(a,c){var b=this.helper.getMenu(a);b.addMouseListener(this.helper);this.updateButton(b,a,null);
b.setName(c);b.setAutoscrolls(!0);return b},"~S,~S");j(c$,"menuRemoveAll",function(a,c){if(0>=c)a.removeAll();else for(var b=a.getComponentCount();--b>=c;)a.remove(b);this.isTainted=!0},"J.api.SC,~N");j(c$,"newMenuItem",function(a,c,b,f,d){this.updateButton(a,b,f);a.addMouseListener(this.helper);a.setName(null==d?c.getName()+".":d);this.menuAddItem(c,a);return a},"J.api.SC,J.api.SC,~S,~S,~S");j(c$,"setText",function(a,c){var b=this.htMenus.get(a);null!=b&&b.setText(c);return b},"~S,~S");j(c$,"menuAddItem",
function(a,c){a.add(c);this.isTainted=!0},"J.api.SC,J.api.SC");j(c$,"menuAddSubMenu",function(a,c){c.addMouseListener(this.helper);this.menuAddItem(a,c)},"J.api.SC,J.api.SC");j(c$,"menuEnable",function(a,c){null==a||a.isEnabled()==c||a.setEnabled(c)},"J.api.SC,~B");j(c$,"menuGetId",function(a){return a.getName()},"J.api.SC");j(c$,"menuSetAutoscrolls",function(a){a.setAutoscrolls(!0);this.isTainted=!0},"J.api.SC");j(c$,"menuGetListPosition",function(a){var c=a.getParent(),b;for(b=c.getComponentCount();0<=
--b&&this.helper.getSwingComponent(c.getComponent(b))!==a;);return b},"J.api.SC");j(c$,"show",function(a,c,b){this.appUpdateForShow();this.updateCheckBoxesForShow();b&&this.menuShowPopup(this.popupMenu,this.thisx,this.thisy)},"~N,~N,~B");j(c$,"updateCheckBoxesForShow",function(){for(var a,c=this.htCheckbox.entrySet().iterator();c.hasNext()&&((a=c.next())||1);){var b=a.getKey(),f=a.getValue(),b=b.substring(0,b.indexOf(":")),b=this.appGetBooleanProperty(b);this.updatingForShow=!0;f.isSelected()!=b&&
(f.setSelected(b),this.isTainted=!0);this.updatingForShow=!1}});n(c$,"jpiGetMenuAsString",function(a){this.appUpdateForShow();var c=a.indexOf("|");if(0<=c){var b=a.substring(c);a=a.substring(0,c);if(0<=b.indexOf("current"))return a=new JU.SB,c=this.htMenus.get(this.menuName),this.menuGetAsText(a,0,c,"PopupMenu"),a.toString()}return this.appGetMenuAsString(a)},"~S");j(c$,"appGetMenuAsString",function(){return null},"~S");j(c$,"menuGetAsText",function(a,c,b,f){b=b.getComponents();for(var d=null,g=null,
m=null,h="S",j=0;j<b.length;j++){var k=this.helper.getSwingComponent(b[j]),l=this.helper.getItemType(k);switch(l){case 4:h="M";f=k.getName();d="enabled:"+k.isEnabled();m=k.getText();g=null;break;case 0:h="S";d=g=m=null;break;default:h="I";d="enabled:"+k.isEnabled();if(2==l||3==l)d+=";checked:"+k.isSelected();g=this.getScriptForCallback(k,k.getName(),k.getActionCommand());f=k.getName();m=k.getText()}J.popup.GenericPopup.addItemText(a,h,c,f,m,g,d);2==l&&this.menuGetAsText(a,c+1,this.helper.getSwingComponent(k.getPopupMenu()),
f)}},"JU.SB,~N,J.api.SC,~S");c$.addItemText=j(c$,"addItemText",function(a,c,b,f,d,g,h){a.appendC(c).appendI(b).appendC("\t").append(f);null==d?a.append(".\n"):a.append("\t").append(d).append("\t").append(null==g||0==g.length?"-":g).append("\t").append(h).append("\n")},"JU.SB,~S,~N,~S,~S,~S,~S");c$.convertToMegabytes=j(c$,"convertToMegabytes",function(a){9223372036854251E3>=a&&(a+=524288);return B(a/1048576)},"~N");n(c$,"jpiDispose",function(){this.popupMenu=this.thisPopup=null;this.helper.dispose(this.popupMenu);
this.helper=null})});r("J.popup");s(["J.popup.GenericPopup","java.util.Properties"],"J.popup.JmolGenericPopup",["J.i18n.GT"],function(){c$=x(function(){this.frankPopup=null;this.nFrankList=0;this.menuText=this.vwr=null;w(this,arguments)},J.popup,"JmolGenericPopup",J.popup.GenericPopup);E(c$,function(){this.menuText=new java.util.Properties});n(c$,"jpiInitialize",function(a,c){var b=J.i18n.GT.setDoTranslate(!0),f=this.getBundle(c);this.initialize(a,f,f.getMenuName());J.i18n.GT.setDoTranslate(b)},"J.api.PlatformViewer,~S");
j(c$,"initialize",function(a,c,b){this.vwr=a;this.initSwing(b,c,a.isJSNoAWT?a.html5Applet:null,a.isJSNoAWT,a.getBooleanProperty("_signedApplet"),a.isWebGL)},"JV.Viewer,J.popup.PopupResource,~S");n(c$,"jpiShow",function(a,c){this.vwr.haveDisplay&&(this.thisx=a,this.thisy=c,this.show(a,c,!1),0>a&&this.showFrankMenu()||(this.appRestorePopupMenu(),this.menuShowPopup(this.popupMenu,this.thisx,this.thisy)))},"~N,~N");j(c$,"showFrankMenu",function(){return!0});j(c$,"jpiDispose",function(){this.vwr=null;
P(this,J.popup.JmolGenericPopup,"jpiDispose",[])});n(c$,"jpiGetMenuAsObject",function(){return this.popupMenu});n(c$,"appFixLabel",function(a){return a},"~S");n(c$,"appGetBooleanProperty",function(a){return this.vwr.getBooleanProperty(a)},"~S");n(c$,"appRunSpecialCheckBox",function(a,c,b,f){if(this.appGetBooleanProperty(c)==f)return!0;if(0>c.indexOf("mk")&&!c.endsWith("P!"))return!1;if(0<=c.indexOf("mk")||0<=c.indexOf("??"))b=this.getUnknownCheckBoxScriptToRun(a,c,b,f);else{if(!f)return!0;b="set picking "+
c.substring(0,c.length-2)}null!=b&&this.appRunScript(b);return!0},"J.api.SC,~S,~S,~B");n(c$,"appRestorePopupMenu",function(){this.thisPopup=this.popupMenu});n(c$,"appRunScript",function(a){this.vwr.evalStringQuiet(a)},"~S")});r("J.popup");s(["J.popup.JmolGenericPopup","JU.Lst"],"J.popup.JmolPopup","java.lang.Boolean java.util.Arrays $.Hashtable JU.PT J.i18n.GT JM.Group J.popup.MainPopupResourceBundle JU.Elements".split(" "),function(){c$=x(function(){this.updateMode=0;this.titleWidthMax=20;this.currentFrankId=
this.modelSetRoot=this.modelSetFileName=this.modelSetName=this.nullModelSetName=null;this.configurationSelected="";this.TemperatureOnly=this.ChargesOnly=this.SymmetryOnly=this.Special=this.VibrationOnly=this.FramesOnly=this.SingleModelOnly=this.UnitcellOnly=this.FileMolOnly=this.FileUnitOnly=this.PDBOnly=this.NotPDB=this.modelInfo=this.modelSetInfo=this.frankList=this.altlocs=null;this.isZapped=this.isVibration=this.isUnitCell=this.hasSymmetry=this.isPDB=this.isMultiFrame=this.isMultiConfiguration=
this.isLastFrame=this.haveCharges=this.haveBFactors=this.fileHasUnitCell=!1;this.ac=this.modelCount=this.modelIndex=0;this.noZapped=this.hnmrPeaks=this.cnmrPeaks=this.group3Counts=this.group3List=null;w(this,arguments)},J.popup,"JmolPopup",J.popup.JmolGenericPopup);E(c$,function(){this.frankList=Array(10);this.NotPDB=new JU.Lst;this.PDBOnly=new JU.Lst;this.FileUnitOnly=new JU.Lst;this.FileMolOnly=new JU.Lst;this.UnitcellOnly=new JU.Lst;this.SingleModelOnly=new JU.Lst;this.FramesOnly=new JU.Lst;this.VibrationOnly=
new JU.Lst;this.Special=new JU.Lst;this.SymmetryOnly=new JU.Lst;this.ChargesOnly=new JU.Lst;this.TemperatureOnly=new JU.Lst;this.noZapped=b(-1,["surfaceMenu","measureMenu","pickingMenu","computationMenu","SIGNEDJAVAcaptureMenuSPECIAL"])});j(c$,"jpiDispose",function(){P(this,J.popup.JmolPopup,"jpiDispose",[]);this.helper.menuClearListeners(this.frankPopup);this.frankPopup=null});n(c$,"getBundle",function(a){return new J.popup.MainPopupResourceBundle(this.strMenuStructure=a,this.menuText)},"~S");n(c$,
"showFrankMenu",function(){this.getViewerData();this.setFrankMenu(this.currentMenuItemId);this.thisx=-this.thisx-50;return 1<this.nFrankList?(this.thisy-=20*this.nFrankList,this.menuShowPopup(this.frankPopup,this.thisx,this.thisy),!1):!0});n(c$,"jpiUpdateComputedMenus",function(){-1!=this.updateMode&&(this.isTainted=!0,this.getViewerData(),this.updateMode=0,this.updateMenus())});j(c$,"updateMenus",function(){this.updateSelectMenu();this.updateModelSetComputedMenu();this.updateAboutSubmenu();if(0==
this.updateMode)this.updateFileMenu(),this.updateElementsComputedMenu(this.vwr.getElementsPresentBitSet(this.modelIndex)),this.updateHeteroComputedMenu(this.vwr.ms.getHeteroList(this.modelIndex)),this.updateSurfMoComputedMenu(this.modelInfo.get("moData")),this.updateFileTypeDependentMenus(),this.updatePDBResidueComputedMenus(),this.updateMode=1,this.updateConfigurationComputedMenu(),this.updateSYMMETRYComputedMenus(),this.updateFRAMESbyModelComputedMenu(),this.updateLanguageSubmenu();else{this.updateSpectraMenu();
this.updateFRAMESbyModelComputedMenu();this.updateSceneComputedMenu();for(var a=this.Special.size();0<=--a;)this.updateSpecialMenuItem(this.Special.get(a))}});n(c$,"appCheckItem",function(a,c){0<=a.indexOf("!PDB")?this.NotPDB.addLast(c):0<=a.indexOf("PDB")&&this.PDBOnly.addLast(c);0<=a.indexOf("CHARGE")?this.ChargesOnly.addLast(c):0<=a.indexOf("BFACTORS")?this.TemperatureOnly.addLast(c):0<=a.indexOf("UNITCELL")?this.UnitcellOnly.addLast(c):0<=a.indexOf("FILEUNIT")?this.FileUnitOnly.addLast(c):0<=
a.indexOf("FILEMOL")&&this.FileMolOnly.addLast(c);0<=a.indexOf("!FRAMES")?this.SingleModelOnly.addLast(c):0<=a.indexOf("FRAMES")&&this.FramesOnly.addLast(c);0<=a.indexOf("VIBRATION")?this.VibrationOnly.addLast(c):0<=a.indexOf("SYMMETRY")&&this.SymmetryOnly.addLast(c);0<=a.indexOf("SPECIAL")&&this.Special.addLast(c)},"~S,J.api.SC");n(c$,"appGetMenuAsString",function(a){return(new J.popup.MainPopupResourceBundle(this.strMenuStructure,null)).getMenuAsText(a)},"~S");n(c$,"getScriptForCallback",function(a,
c,b){if(""===b||c.endsWith("Checkbox"))return b;if(0==b.indexOf("SELECT"))return"select thisModel and ("+b.substring(6)+")";if(0<=(a=c.lastIndexOf("["))){c=c.substring(a+1);if(0<=(a=c.indexOf("]")))c=c.substring(0,a);c=c.$replace("_"," ");0>b.indexOf("[]")&&(b="[] "+b);b=b.$replace("_"," ");return JU.PT.rep(b,"[]",c)}0<=b.indexOf("?FILEROOT?")?b=JU.PT.rep(b,"FILEROOT?",this.modelSetRoot):0<=b.indexOf("?FILE?")?b=JU.PT.rep(b,"FILE?",this.modelSetFileName):0<=b.indexOf("?PdbId?")&&(b=JU.PT.rep(b,"PdbId?",
"=xxxx"));return b},"J.api.SC,~S,~S");n(c$,"appRestorePopupMenu",function(){this.thisPopup=this.popupMenu;if(!(this.vwr.isJSNoAWT||2>this.nFrankList)){for(var a=this.nFrankList;0<--a;){var c=this.frankList[a];this.helper.menuInsertSubMenu(c[0],c[1],c[2].intValue())}this.nFrankList=1}});n(c$,"appUpdateSpecialCheckBoxValue",function(a,c){!this.updatingForShow&&0<=c.indexOf("#CONFIG")&&(this.configurationSelected=c,this.updateConfigurationComputedMenu(),this.updateModelSetComputedMenu())},"J.api.SC,~S,~B");
j(c$,"setFrankMenu",function(a){if(!(null!=this.currentFrankId&&this.currentFrankId===a&&0<this.nFrankList)){null==this.frankPopup&&(this.frankPopup=this.helper.menuCreatePopup("Frank",this.vwr.html5Applet));this.thisPopup=this.frankPopup;this.menuRemoveAll(this.frankPopup,0);this.menuCreateItem(this.frankPopup,this.getMenuText("mainMenuText"),"MAIN","");this.currentFrankId=a;this.nFrankList=0;this.frankList[this.nFrankList++]=b(-1,[null,null,null]);if(null!=a)for(var c=a.indexOf(".",2)+1;;){var e=
a.indexOf(".",c);if(0>e)break;c=this.htMenus.get(a.substring(c,e));this.frankList[this.nFrankList++]=b(-1,[c.getParent(),c,Integer.$valueOf(this.vwr.isJSNoAWT?0:this.menuGetListPosition(c))]);this.menuAddSubMenu(this.frankPopup,c);c=e+1}this.thisPopup=this.popupMenu}},"~S");j(c$,"checkBoolean",function(a){return null!=this.modelSetInfo&&this.modelSetInfo.get(a)===Boolean.TRUE},"~S");j(c$,"getViewerData",function(){this.modelSetName=this.vwr.ms.modelSetName;this.modelSetFileName=this.vwr.getModelSetFileName();
var a=this.modelSetFileName.lastIndexOf(".");if((this.isZapped="zapped".equals(this.modelSetName))||"string".equals(this.modelSetFileName)||"String[]".equals(this.modelSetFileName))this.modelSetFileName="";this.modelSetRoot=this.modelSetFileName.substring(0,0>a?this.modelSetFileName.length:a);0==this.modelSetRoot.length&&(this.modelSetRoot="Jmol");this.modelIndex=this.vwr.am.cmi;this.modelCount=this.vwr.ms.mc;this.ac=this.vwr.ms.getAtomCountInModel(this.modelIndex);this.modelSetInfo=this.vwr.getModelSetAuxiliaryInfo();
this.modelInfo=this.vwr.ms.getModelAuxiliaryInfo(this.modelIndex);null==this.modelInfo&&(this.modelInfo=new java.util.Hashtable);this.isPDB=this.checkBoolean("isPDB");this.isMultiFrame=1<this.modelCount;this.hasSymmetry=this.modelInfo.containsKey("hasSymmetry");this.isUnitCell=this.modelInfo.containsKey("unitCellParams");this.fileHasUnitCell=this.isPDB&&this.isUnitCell||this.checkBoolean("fileHasUnitCell");this.isLastFrame=this.modelIndex==this.modelCount-1;this.altlocs=this.vwr.ms.getAltLocListInModel(this.modelIndex);
this.isMultiConfiguration=0<this.altlocs.length;this.isVibration=this.vwr.modelHasVibrationVectors(this.modelIndex);this.haveCharges=null!=this.vwr.ms.getPartialCharges();this.haveBFactors=this.vwr.getBooleanProperty("haveBFactors");this.cnmrPeaks=this.modelInfo.get("jdxAtomSelect_13CNMR");this.hnmrPeaks=this.modelInfo.get("jdxAtomSelect_1HNMR")});n(c$,"appCheckSpecialMenu",function(a,c,b){"modelSetMenu".equals(a)&&(this.nullModelSetName=b,this.menuEnable(c,!1))},"~S,J.api.SC,~S");n(c$,"appUpdateForShow",
function(){-1!=this.updateMode&&(this.isTainted=!0,this.getViewerData(),this.updateMode=2,this.updateMenus())});j(c$,"updateFileMenu",function(){var a=this.htMenus.get("fileMenu");if(null!=a){var c=this.getMenuText("writeFileTextVARIABLE"),a=this.htMenus.get("writeFileTextVARIABLE");null!=a&&(this.modelSetFileName.equals("zapped")||this.modelSetFileName.equals("")?(this.menuSetLabel(a,""),this.menuEnable(a,!1)):(this.menuSetLabel(a,J.i18n.GT.o(J.i18n.GT.$(c),this.modelSetFileName)),this.menuEnable(a,
!0)))}});j(c$,"getMenuText",function(a){var c=this.menuText.getProperty(a);return null==c?a:c},"~S");j(c$,"updateSelectMenu",function(){var a=this.htMenus.get("selectMenuText");null!=a&&(this.menuEnable(a,0!=this.ac),this.menuSetLabel(a,this.gti("selectMenuText",this.vwr.slm.getSelectionCount())))});j(c$,"updateElementsComputedMenu",function(a){var c=this.htMenus.get("elementsComputedMenu");if(null!=c&&(this.menuRemoveAll(c,0),this.menuEnable(c,!1),null!=a)){for(var b=a.nextSetBit(0);0<=b;b=a.nextSetBit(b+
1)){var f=JU.Elements.elementNameFromNumber(b),d=JU.Elements.elementSymbolFromNumber(b),d=d+" - "+f;this.menuCreateItem(c,d,"SELECT "+f,null)}for(b=4;b<JU.Elements.altElementMax;++b)d=JU.Elements.elementNumberMax+b,a.get(d)&&(d=JU.Elements.altElementNumberFromIndex(b),f=JU.Elements.elementNameFromNumber(d),d=JU.Elements.elementSymbolFromNumber(d),d=d+" - "+f,this.menuCreateItem(c,d,"SELECT "+f,null));this.menuEnable(c,!0)}},"JU.BS");j(c$,"updateSpectraMenu",function(){var a=this.htMenus.get("spectraMenu");
if(null!=a){var b=this.htMenus.get("hnmrMenu");null!=b&&this.menuRemoveAll(b,0);var e=this.htMenus.get("cnmrMenu");null!=e&&this.menuRemoveAll(e,0);this.menuRemoveAll(a,0);var f=(new Boolean(this.setSpectraMenu(b,this.hnmrPeaks)|this.setSpectraMenu(e,this.cnmrPeaks))).valueOf();f&&(null!=b&&this.menuAddSubMenu(a,b),null!=e&&this.menuAddSubMenu(a,e));this.menuEnable(a,f)}});j(c$,"setSpectraMenu",function(a,b){var e=null==b?0:b.size();if(0==e||null==a)return!1;this.menuEnable(a,!1);for(var f=0;f<e;f++){var d=
b.get(f),g=JU.PT.getQuotedAttribute(d,"title"),d=JU.PT.getQuotedAttribute(d,"atoms");null!=d&&this.menuCreateItem(a,g,"select visible & (@"+JU.PT.rep(d,","," or @")+")","Focus"+f)}this.menuEnable(a,!0);return!0},"J.api.SC,JU.Lst");j(c$,"updateHeteroComputedMenu",function(a){var b=this.htMenus.get("PDBheteroComputedMenu");if(null!=b&&(this.menuRemoveAll(b,0),this.menuEnable(b,!1),null!=a)){var e=0,f;for(a=a.entrySet().iterator();a.hasNext()&&((f=a.next())||1);){var d=f.getKey(),g=f.getValue();20<g.length&&
(g=g.substring(0,20)+"...");this.menuCreateItem(b,d+" - "+g,"SELECT ["+d+"]",null);e++}this.menuEnable(b,0<e)}},"java.util.Map");j(c$,"updateSurfMoComputedMenu",function(a){var b=this.htMenus.get("surfMoComputedMenuText");if(null!=b){this.menuRemoveAll(b,0);a=null==a?null:a.get("mos");var e=null==a?0:a.size(),f=this.getMenuText("surfMoComputedMenuText");if(0==e)this.menuSetLabel(b,J.i18n.GT.o(J.i18n.GT.$(f),"")),this.menuEnable(b,!1);else{this.menuSetLabel(b,J.i18n.GT.i(J.i18n.GT.$(f),e));this.menuEnable(b,
!0);var f=b,d=e%25;0==d&&(d=25);for(var g=25<e?0:-2147483648;0<=--e;){0<=g&&0==g++%d&&(g==d+1&&(d=25),g="mo"+g+"Menu",f=this.menuNewSubMenu(Math.max(e+2-d,1)+"..."+(e+1),this.menuGetId(b)+"."+g),this.menuAddSubMenu(b,f),this.htMenus.put(g,f),g=1);var h=a.get(e),h="#"+(e+1)+" "+(h.containsKey("type")?h.get("type")+" ":"")+(h.containsKey("symmetry")?h.get("symmetry")+" ":"")+(h.containsKey("occupancy")?"("+h.get("occupancy")+") ":"")+(h.containsKey("energy")?h.get("energy"):"");this.menuCreateItem(f,
h,"mo "+(e+1),null)}}}},"java.util.Map");j(c$,"updateFileTypeDependentMenus",function(){for(var a=this.NotPDB.size();0<=--a;)this.menuEnable(this.NotPDB.get(a),!this.isPDB);for(a=this.PDBOnly.size();0<=--a;)this.menuEnable(this.PDBOnly.get(a),this.isPDB);for(a=this.UnitcellOnly.size();0<=--a;)this.menuEnable(this.UnitcellOnly.get(a),this.isUnitCell);for(a=this.FileUnitOnly.size();0<=--a;)this.menuEnable(this.FileUnitOnly.get(a),this.isUnitCell||this.fileHasUnitCell);for(a=this.FileMolOnly.size();0<=
--a;)this.menuEnable(this.FileMolOnly.get(a),this.isUnitCell||this.fileHasUnitCell);for(a=this.SingleModelOnly.size();0<=--a;)this.menuEnable(this.SingleModelOnly.get(a),this.isLastFrame);for(a=this.FramesOnly.size();0<=--a;)this.menuEnable(this.FramesOnly.get(a),this.isMultiFrame);for(a=this.VibrationOnly.size();0<=--a;)this.menuEnable(this.VibrationOnly.get(a),this.isVibration);for(a=this.SymmetryOnly.size();0<=--a;)this.menuEnable(this.SymmetryOnly.get(a),this.hasSymmetry&&this.isUnitCell);for(a=
this.ChargesOnly.size();0<=--a;)this.menuEnable(this.ChargesOnly.get(a),this.haveCharges);for(a=this.TemperatureOnly.size();0<=--a;)this.menuEnable(this.TemperatureOnly.get(a),this.haveBFactors);this.updateSignedAppletItems()});j(c$,"updateSceneComputedMenu",function(){var a=this.htMenus.get("sceneComputedMenu");if(null!=a){this.menuRemoveAll(a,0);this.menuEnable(a,!1);var b=this.vwr.ms.getInfoM("scenes");if(null!=b){for(var e=0;e<b.length;e++)this.menuCreateItem(a,b[e],"restore scene "+JU.PT.esc(b[e])+
" 1.0",null);this.menuEnable(a,!0)}}});j(c$,"updatePDBResidueComputedMenus",function(){var a=!1,b=this.htMenus.get("PDBaaResiduesComputedMenu");null!=b&&(this.menuRemoveAll(b,0),this.menuEnable(b,!1),a=!0);var e=this.htMenus.get("PDBnucleicResiduesComputedMenu");null!=e&&(this.menuRemoveAll(e,0),this.menuEnable(e,!1),a=!0);var f=this.htMenus.get("PDBcarboResiduesComputedMenu");null!=f&&(this.menuRemoveAll(f,0),this.menuEnable(f,!1),a=!0);if(null!=this.modelSetInfo&&a){var a=0>this.modelIndex?0:this.modelIndex+
1,d=this.modelSetInfo.get("group3Lists");this.group3List=null==d?null:d[a];this.group3Counts=null==d?null:this.modelSetInfo.get("group3Counts")[a];if(null!=this.group3List){a=0;d=JM.Group.standardGroupList;if(null!=b){for(var g=1;24>g;++g)a+=this.updateGroup3List(b,d.substring(6*g-4,6*g-1).trim());a+=this.augmentGroup3List(b,"p>",!0);this.menuEnable(b,0<a);this.menuEnable(this.htMenus.get("PDBproteinMenu"),0<a)}null!=e&&(a=this.augmentGroup3List(e,"n>",!1),this.menuEnable(e,0<a),this.menuEnable(this.htMenus.get("PDBnucleicMenu"),
0<a),b=0<a&&0<=this.modelIndex?this.vwr.ms.getInfo(this.modelIndex,"dssr"):null,null!=b&&this.setSecStrucMenu(this.htMenus.get("aaStructureMenu"),b));null!=f&&(a=this.augmentGroup3List(f,"c>",!1),this.menuEnable(f,0<a),this.menuEnable(this.htMenus.get("PDBcarboMenu"),0<a))}}});j(c$,"setSecStrucMenu",function(a,b){var e=b.get("counts");if(null==e)return!1;var f=Array(e.size());e.keySet().toArray(f);java.util.Arrays.sort(f);if(0==f.length)return!1;a.removeAll();for(var d=0;d<f.length;d++)this.menuCreateItem(a,
f[d]+" ("+e.get(f[d])+")","select modelIndex="+this.modelIndex+" && within('dssr', '"+f[d]+"');",null);return!0},"J.api.SC,java.util.Map");j(c$,"updateGroup3List",function(a,b){var e=0,f=this.group3Counts[B(this.group3List.indexOf(b)/6)];b=b.trim();var d=null;0<f&&(d="SELECT "+b,b+="  ("+f+")",e++);d=this.menuCreateItem(a,b,d,this.menuGetId(a)+"."+b);0==f&&this.menuEnable(d,!1);return e},"J.api.SC,~S");j(c$,"augmentGroup3List",function(a,b,e){for(var f=138,d=0;;){f=this.group3List.indexOf(b,f);if(0>
f)break;0==d++&&e&&this.menuAddSeparator(a);var g=this.group3Counts[B(f/6)],h=this.group3List.substring(f+2,f+5),g=h+"  ("+g+")";this.menuCreateItem(a,g,"SELECT ["+h+"]",this.menuGetId(a)+"."+g);f++}return d},"J.api.SC,~S,~B");j(c$,"updateSYMMETRYComputedMenus",function(){this.updateSYMMETRYSelectComputedMenu();this.updateSYMMETRYShowComputedMenu()});j(c$,"updateSYMMETRYShowComputedMenu",function(){var a=this.htMenus.get("SYMMETRYShowComputedMenu");if(null!=a&&(this.menuRemoveAll(a,0),this.menuEnable(a,
!1),this.hasSymmetry&&!(0>this.modelIndex))){var b=this.vwr.getProperty("DATA_API","spaceGroupInfo",null);if(null!=b){var e=b.get("operations");if(null!=e){b=b.get("spaceGroupName");this.menuSetLabel(a,null==b?J.i18n.GT.$("Space Group"):b);for(var b=a,f=25<e.length?0:-2147483648,d=0;d<e.length;d++){0<=f&&0==f++%25&&(f="drawsymop"+f+"Menu",b=this.menuNewSubMenu(d+1+"..."+Math.min(d+25,e.length),this.menuGetId(a)+"."+f),this.menuAddSubMenu(a,b),this.htMenus.put(f,b),f=1);0==d&&this.menuEnable(this.menuCreateItem(b,
J.i18n.GT.$("none"),"draw sym_* delete",null),!0);var g=e[d][1];0>g.indexOf("x1")&&(g=e[d][0]);this.menuEnable(this.menuCreateItem(b,d+1+" "+e[d][2]+" ("+g+")","draw SYMOP "+(d+1),null),!0)}this.menuEnable(a,!0)}}}});j(c$,"updateSYMMETRYSelectComputedMenu",function(){var a=this.htMenus.get("SYMMETRYSelectComputedMenu");if(null!=a&&(this.menuRemoveAll(a,0),this.menuEnable(a,!1),this.hasSymmetry&&!(0>this.modelIndex))){var b=this.modelInfo.get("symmetryOperations");if(null!=b){for(var e=null!=this.modelInfo.get("unitCellRange"),
f=a,d=25<b.length?0:-2147483648,g=0;g<b.length;g++)0<=d&&0==d++%25&&(d="symop"+d+"Menu",f=this.menuNewSubMenu(g+1+"..."+Math.min(g+25,b.length),this.menuGetId(a)+"."+d),this.menuAddSubMenu(a,f),this.htMenus.put(d,f),d=1),this.menuEnable(this.menuCreateItem(f,"symop="+(g+1)+" # "+b[g],"SELECT symop="+(g+1),null),e);this.menuEnable(a,!0)}}});j(c$,"updateFRAMESbyModelComputedMenu",function(){var a=this.htMenus.get("FRAMESbyModelComputedMenu");if(null!=a&&(this.menuEnable(a,0<this.modelCount),this.menuSetLabel(a,
0>this.modelIndex?this.gti("allModelsText",this.modelCount):this.gto("modelMenuText",this.modelIndex+1+"/"+this.modelCount)),this.menuRemoveAll(a,0),!(1>this.modelCount))){1<this.modelCount&&this.menuCreateCheckboxItem(a,J.i18n.GT.$("All"),"frame 0 ##",null,0>this.modelIndex,!1);for(var b=a,e=25<this.modelCount?0:-2147483648,f=0;f<this.modelCount;f++){0<=e&&0==e++%25&&(e="model"+e+"Menu",b=this.menuNewSubMenu(f+1+"..."+Math.min(f+25,this.modelCount),this.menuGetId(a)+"."+e),this.menuAddSubMenu(a,
b),this.htMenus.put(e,b),e=1);var d=""+this.vwr.getModelNumberDotted(f),g=this.vwr.getModelName(f),h=this.vwr.ms.getInfo(f,"spectrumTypes");null!=h&&g.startsWith(h)&&(h=null);if(!g.equals(d)){var j=g.indexOf(";PATH");0<=j&&(g=g.substring(0,j));if(0==g.indexOf("Model[")&&0<=(j=g.indexOf("]:")))g=g.substring(j+2);g=d+": "+g}60<g.length&&(g=g.substring(0,55)+"...");null!=h&&(g+=" ("+h+")");this.menuCreateCheckboxItem(b,g,"model "+d+" ##",null,this.modelIndex==f,!1)}}});j(c$,"updateConfigurationComputedMenu",
function(){var a=this.htMenus.get("configurationComputedMenu");if(null!=a&&(this.menuEnable(a,this.isMultiConfiguration),this.isMultiConfiguration)){var b=this.altlocs.length;this.menuSetLabel(a,this.gti("configurationMenuText",b));this.menuRemoveAll(a,0);var e="hide none ##CONFIG";this.menuCreateCheckboxItem(a,J.i18n.GT.$("All"),e,null,1==this.updateMode&&this.configurationSelected.equals(e),!1);for(var f=0;f<b;f++){var e="configuration "+(f+1)+"; hide thisModel and not selected ##CONFIG",d=""+(f+
1)+' -- "'+this.altlocs.charAt(f)+'"';this.menuCreateCheckboxItem(a,d,e,null,1==this.updateMode&&this.configurationSelected.equals(e),!1)}}});j(c$,"updateModelSetComputedMenu",function(){var a=this.htMenus.get("modelSetMenu");if(null!=a){this.menuRemoveAll(a,0);this.menuSetLabel(a,this.nullModelSetName);this.menuEnable(a,!1);for(var c=this.noZapped.length;0<=--c;)this.menuEnable(this.htMenus.get(this.noZapped[c]),!this.isZapped);if(!(null==this.modelSetName||this.isZapped)){this.isMultiFrame?(this.modelSetName=
this.gti("modelSetCollectionText",this.modelCount),this.modelSetName.length>this.titleWidthMax&&(this.modelSetName=this.modelSetName.substring(0,this.titleWidthMax)+"...")):this.vwr.getBooleanProperty("hideNameInPopup")?this.modelSetName=this.getMenuText("hiddenModelSetText"):this.modelSetName.length>this.titleWidthMax&&(this.modelSetName=this.modelSetName.substring(0,this.titleWidthMax)+"...");this.menuSetLabel(a,this.modelSetName);this.menuEnable(a,!0);this.menuEnable(this.htMenus.get("computationMenu"),
100>=this.ac);this.addMenuItem(a,this.gti("atomsText",this.ac));this.addMenuItem(a,this.gti("bondsText",this.vwr.ms.getBondCountInModel(this.modelIndex)));if(this.isPDB){this.menuAddSeparator(a);this.addMenuItem(a,this.gti("groupsText",this.vwr.ms.getGroupCountInModel(this.modelIndex)));this.addMenuItem(a,this.gti("chainsText",this.vwr.ms.getChainCountInModelWater(this.modelIndex,!1)));this.addMenuItem(a,this.gti("polymersText",this.vwr.ms.getBioPolymerCountInModel(this.modelIndex)));var e=this.htMenus.get("BiomoleculesMenu");
null==e&&(e=this.menuNewSubMenu(J.i18n.GT.$(this.getMenuText("biomoleculesMenuText")),this.menuGetId(a)+".biomolecules"),this.menuAddSubMenu(a,e));this.menuRemoveAll(e,0);this.menuEnable(e,!1);var f;if(0<=this.modelIndex&&null!=(f=this.vwr.ms.getInfo(this.modelIndex,"biomolecules"))){this.menuEnable(e,!0);for(var d=f.size(),c=0;c<d;c++){var g=this.isMultiFrame?"":'save orientation;load "" FILTER "biomolecule '+(c+1)+'";restore orientation;',h=f.get(c).get("atomCount").intValue(),h=this.gto(this.isMultiFrame?
"biomoleculeText":"loadBiomoleculeText",b(-1,[Integer.$valueOf(c+1),Integer.$valueOf(h)]));this.menuCreateItem(e,h,g,null)}}}this.isApplet&&!this.vwr.getBooleanProperty("hideNameInPopup")&&(this.menuAddSeparator(a),this.menuCreateItem(a,this.gto("viewMenuText",this.modelSetFileName),"show url",null))}}});j(c$,"gti",function(a,b){return J.i18n.GT.i(J.i18n.GT.$(this.getMenuText(a)),b)},"~S,~N");j(c$,"gto",function(a,b){return J.i18n.GT.o(J.i18n.GT.$(this.getMenuText(a)),b)},"~S,~O");j(c$,"updateAboutSubmenu",
function(){this.isApplet&&this.setText("APPLETid",this.vwr.appletName)});j(c$,"updateLanguageSubmenu",function(){var a=this.htMenus.get("languageComputedMenu");if(null!=a){this.menuRemoveAll(a,0);for(var b=J.i18n.GT.getLanguage(),e=this.menuGetId(a),f=J.i18n.GT.getLanguageList(null),d=0,g=0;d<f.length;d++)if(b.equals(f[d].code)&&(f[d].display=!0),f[d].display){var h=f[d].code,j=f[d].language,k=f[d].nativeLanguage,l=h+" - "+J.i18n.GT.$(j);null!=k&&!k.equals(J.i18n.GT.$(j))&&(l+=" - "+k);0<g++&&1==
g%4&&this.menuAddSeparator(a);this.menuCreateCheckboxItem(a,l,'language = "'+h+'" ##'+j,e+"."+h,b.equals(h),!1)}}});j(c$,"updateSpecialMenuItem",function(a){a.setText(this.getSpecialLabel(a.getName(),a.getText()))},"J.api.SC");j(c$,"getSpecialLabel",function(a,b){var e=b.indexOf(" (");0>e&&(e=b.length);var f=null;0<=a.indexOf("captureLooping")?f=1073742070==this.vwr.am.animationReplayMode?"ONCE":"LOOP":0<=a.indexOf("captureFps")?f=""+this.vwr.getInt(553648132):0<=a.indexOf("captureMenu")&&(f=null==
this.vwr.captureParams?J.i18n.GT.$("not capturing"):this.vwr.fm.getFilePath(this.vwr.captureParams.get("captureFileName"),!1,!0)+" "+this.vwr.captureParams.get("captureCount"));return null==f?b:b.substring(0,e)+" ("+f+")"},"~S,~S");N(c$,"UPDATE_NEVER",-1,"UPDATE_ALL",0,"UPDATE_CONFIG",1,"UPDATE_SHOW",2,"itemMax",25,"MENUITEM_HEIGHT",20)});r("J.popup");s(["J.popup.PopupResource"],"J.popup.MainPopupResourceBundle",["JU.PT","J.i18n.GT","JV.JC","$.Viewer"],function(){c$=O(J.popup,"MainPopupResourceBundle",
J.popup.PopupResource);n(c$,"getMenuName",function(){return"popupMenu"});n(c$,"buildStructure",function(a){this.addItems(J.popup.MainPopupResourceBundle.menuContents);this.addItems(J.popup.MainPopupResourceBundle.structureContents);null!=a&&this.setStructure(a,new J.i18n.GT)},"~S");c$.Box=j(c$,"Box",function(a){return"if (showBoundBox or showUnitcell) {"+a+"} else {boundbox on;"+a+";boundbox off}"},"~S");n(c$,"getWordContents",function(){var a=J.i18n.GT.setDoTranslate(!0),c=J.i18n.GT.$("{0}% van der Waals"),
e=J.i18n.GT.$("Export {0} 3D model"),f=J.i18n.GT.$("Export {0} image"),d=J.i18n.GT.$("Reload {0}"),g=J.i18n.GT.$("Scale {0}"),h=J.i18n.GT.$("{0} \u00c5"),j=J.i18n.GT.$("{0} px"),c=b(-1,["cnmrMenu",J.i18n.GT.$("13C-NMR"),"hnmrMenu",J.i18n.GT.$("1H-NMR"),"aboutMenu",J.i18n.GT.$("About..."),"negativeCharge",J.i18n.GT.$("Acidic Residues (-)"),"allModelsText",J.i18n.GT.$("All {0} models"),"allHetero",J.i18n.GT.$('All PDB "HETATM"'),"Solvent",J.i18n.GT.$("All Solvent"),"Water",J.i18n.GT.$("All Water"),
"selectAll",J.i18n.GT.$("All"),"allProtein",null,"allNucleic",null,"allCarbo",null,"altloc#PDB",J.i18n.GT.$("Alternative Location"),"amino#PDB",J.i18n.GT.$("Amino Acid"),"byAngstromMenu",J.i18n.GT.$("Angstrom Width"),"animModeMenu",J.i18n.GT.$("Animation Mode"),"FRAMESanimateMenu",J.i18n.GT.$("Animation"),"atPairs",J.i18n.GT.$("AT pairs"),"atomMenu",J.i18n.GT.$("Atoms"),"[color_atoms]Menu",null,"atomsText",J.i18n.GT.$("atoms: {0}"),"auPairs",J.i18n.GT.$("AU pairs"),"[color_axes]Menu",J.i18n.GT.$("Axes"),
"showAxesCB",null,"[set_axes]Menu",null,"axisA",J.i18n.GT.$("Axis a"),"axisB",J.i18n.GT.$("Axis b"),"axisC",J.i18n.GT.$("Axis c"),"axisX",J.i18n.GT.$("Axis x"),"axisY",J.i18n.GT.$("Axis y"),"axisZ",J.i18n.GT.$("Axis z"),"back",J.i18n.GT.$("Back"),"proteinBackbone",J.i18n.GT.$("Backbone"),"nucleicBackbone",null,"backbone",null,"[color_backbone]Menu",null,"[color_background]Menu",J.i18n.GT.$("Background"),"renderBallAndStick",J.i18n.GT.$("Ball and Stick"),"nucleicBases",J.i18n.GT.$("Bases"),"positiveCharge",
J.i18n.GT.$("Basic Residues (+)"),"best",J.i18n.GT.$("Best"),"biomoleculeText",J.i18n.GT.$("biomolecule {0} ({1} atoms)"),"biomoleculesMenuText",J.i18n.GT.$("Biomolecules"),"black",J.i18n.GT.$("Black"),"blue",J.i18n.GT.$("Blue"),"bondMenu",J.i18n.GT.$("Bonds"),"[color_bonds]Menu",null,"bondsText",J.i18n.GT.$("bonds: {0}"),"bottom",J.i18n.GT.$("Bottom"),"[color_boundbox]Menu",J.i18n.GT.$("Boundbox"),"[set_boundbox]Menu",null,"showBoundBoxCB",null,"PDBheteroComputedMenu",J.i18n.GT.$("By HETATM"),"PDBaaResiduesComputedMenu",
J.i18n.GT.$("By Residue Name"),"PDBnucleicResiduesComputedMenu",null,"PDBcarboResiduesComputedMenu",null,"schemeMenu",J.i18n.GT.$("By Scheme"),"[color_]schemeMenu",null,"hbondCalc",J.i18n.GT.$("Calculate"),"SIGNEDJAVAcaptureRock",J.i18n.GT.$("Capture rock"),"SIGNEDJAVAcaptureSpin",J.i18n.GT.$("Capture spin"),"SIGNEDJAVAcaptureMenuSPECIAL",J.i18n.GT.$("Capture"),"PDBcarboMenu",J.i18n.GT.$("Carbohydrate"),"cartoonRockets",J.i18n.GT.$("Cartoon Rockets"),"PDBrenderCartoonsOnly",J.i18n.GT.$("Cartoon"),
"cartoon",null,"[color_cartoon]sMenu",null,"pickCenter",J.i18n.GT.$("Center"),"labelCentered",J.i18n.GT.$("Centered"),"chain#PDB",J.i18n.GT.$("Chain"),"chainsText",J.i18n.GT.$("chains: {0}"),"colorChargeMenu",J.i18n.GT.$("Charge"),"measureAngle",J.i18n.GT.$("Click for angle measurement"),"measureDistance",J.i18n.GT.$("Click for distance measurement"),"measureTorsion",J.i18n.GT.$("Click for torsion (dihedral) measurement"),"PDBmeasureSequence",J.i18n.GT.$("Click two atoms to display a sequence in the console"),
"modelSetCollectionText",J.i18n.GT.$("Collection of {0} models"),"colorMenu",J.i18n.GT.$("Color"),"computationMenu",J.i18n.GT.$("Computation"),"configurationMenuText",J.i18n.GT.$("Configurations ({0})"),"configurationComputedMenu",J.i18n.GT.$("Configurations"),"showConsole",J.i18n.GT.$("Console"),"renderCpkSpacefill",J.i18n.GT.$("CPK Spacefill"),"stereoCrossEyed",J.i18n.GT.$("Cross-eyed viewing"),"showState",J.i18n.GT.$("Current state"),"cyan",J.i18n.GT.$("Cyan"),"darkgray",J.i18n.GT.$("Dark Gray"),
"measureDelete",J.i18n.GT.$("Delete measurements"),"SIGNEDJAVAcaptureOff",J.i18n.GT.$("Disable capturing"),"hideNotSelectedCB",J.i18n.GT.$("Display Selected Only"),"distanceAngstroms",J.i18n.GT.$("Distance units Angstroms"),"distanceNanometers",J.i18n.GT.$("Distance units nanometers"),"distancePicometers",J.i18n.GT.$("Distance units picometers"),"distanceHz",J.i18n.GT.$("Distance units hz (NMR J-coupling)"),"ssbondMenu",J.i18n.GT.$("Disulfide Bonds"),"[color_ssbonds]Menu",null,"DNA",J.i18n.GT.$("DNA"),
"surfDots",J.i18n.GT.$("Dot Surface"),"dotted",J.i18n.GT.$("Dotted"),"measureOff",J.i18n.GT.$("Double-Click begins and ends all measurements"),"cpk",J.i18n.GT.$("Element (CPK)"),"elementsComputedMenu",J.i18n.GT.$("Element"),"SIGNEDJAVAcaptureEnd",J.i18n.GT.$("End capturing"),"exportMenu",J.i18n.GT.$("Export"),"extractMOL",J.i18n.GT.$("Extract MOL data"),"showFile",J.i18n.GT.$("File Contents"),"showFileHeader",J.i18n.GT.$("File Header"),"fileMenu",J.i18n.GT.$("File"),"formalcharge",J.i18n.GT.$("Formal Charge"),
"front",J.i18n.GT.$("Front"),"gcPairs",J.i18n.GT.$("GC pairs"),"gold",J.i18n.GT.$("Gold"),"gray",J.i18n.GT.$("Gray"),"green",J.i18n.GT.$("Green"),"group#PDB",J.i18n.GT.$("Group"),"groupsText",J.i18n.GT.$("groups: {0}"),"PDBheteroMenu",J.i18n.GT.$("Hetero"),"off#axes",J.i18n.GT.$("Hide"),"showHistory",J.i18n.GT.$("History"),"hbondMenu",J.i18n.GT.$("Hydrogen Bonds"),"[color_hbonds]Menu",null,"pickIdent",J.i18n.GT.$("Identity"),"indigo",J.i18n.GT.$("Indigo"),"none",J.i18n.GT.$("Inherit"),"invertSelection",
J.i18n.GT.$("Invert Selection"),"showIsosurface",J.i18n.GT.$("Isosurface JVXL data"),"help",J.i18n.GT.$("Jmol Script Commands"),"pickLabel",J.i18n.GT.$("Label"),"labelMenu",J.i18n.GT.$("Labels"),"[color_labels]Menu",null,"languageComputedMenu",J.i18n.GT.$("Language"),"left",J.i18n.GT.$("Left"),"Ligand",J.i18n.GT.$("Ligand"),"lightgray",J.i18n.GT.$("Light Gray"),"measureList",J.i18n.GT.$("List measurements"),"loadBiomoleculeText",J.i18n.GT.$("load biomolecule {0} ({1} atoms)"),"SIGNEDloadFileUnitCell",
J.i18n.GT.$("Load full unit cell"),"loadMenu",J.i18n.GT.$("Load"),"loop",J.i18n.GT.$("Loop"),"labelLowerLeft",J.i18n.GT.$("Lower Left"),"labelLowerRight",J.i18n.GT.$("Lower Right"),"mainMenuText",J.i18n.GT.$("Main Menu"),"opaque",J.i18n.GT.$("Make Opaque"),"surfOpaque",null,"translucent",J.i18n.GT.$("Make Translucent"),"surfTranslucent",null,"maroon",J.i18n.GT.$("Maroon"),"measureMenu",J.i18n.GT.$("Measurements"),"showMeasure",null,"modelMenuText",J.i18n.GT.$("model {0}"),"hiddenModelSetText",J.i18n.GT.$("Model information"),
"modelkit",J.i18n.GT.$("Model kit"),"showModel",J.i18n.GT.$("Model"),"FRAMESbyModelComputedMenu",J.i18n.GT.$("Model/Frame"),"modelKitMode",J.i18n.GT.$("modelKitMode"),"surf2MEP",J.i18n.GT.$("Molecular Electrostatic Potential (range -0.1 0.1)"),"surfMEP",J.i18n.GT.$("Molecular Electrostatic Potential (range ALL)"),"showMo",J.i18n.GT.$("Molecular orbital JVXL data"),"surfMoComputedMenuText",J.i18n.GT.$("Molecular Orbitals ({0})"),"surfMolecular",J.i18n.GT.$("Molecular Surface"),"molecule",J.i18n.GT.$("Molecule"),
"monomer#PDB",J.i18n.GT.$("Monomer"),"mouse",J.i18n.GT.$("Mouse Manual"),"nextframe",J.i18n.GT.$("Next Frame"),"modelSetMenu",J.i18n.GT.$("No atoms loaded"),"exceptWater",J.i18n.GT.$("Nonaqueous HETATM")+" (hetero and not water)","nonWaterSolvent",J.i18n.GT.$("Nonaqueous Solvent")+" (solvent and not water)","PDBnoneOfTheAbove",J.i18n.GT.$("None of the above"),"selectNone",J.i18n.GT.$("None"),"stereoNone",null,"labelNone",null,"nonpolar",J.i18n.GT.$("Nonpolar Residues"),"PDBnucleicMenu",J.i18n.GT.$("Nucleic"),
"atomNone",J.i18n.GT.$("Off"),"bondNone",null,"hbondNone",null,"ssbondNone",null,"structureNone",null,"vibrationOff",null,"vectorOff",null,"spinOff",null,"pickOff",null,"surfOff",null,"olive",J.i18n.GT.$("Olive"),"bondWireframe",J.i18n.GT.$("On"),"hbondWireframe",null,"ssbondWireframe",null,"vibrationOn",null,"vectorOn",null,"spinOn",null,"on",null,"SIGNEDloadPdb",J.i18n.GT.$("Open from PDB"),"SIGNEDloadFile",J.i18n.GT.$("Open local file"),"SIGNEDloadScript",J.i18n.GT.$("Open script"),"SIGNEDloadUrl",
J.i18n.GT.$("Open URL"),"minimize",J.i18n.GT.$("Optimize structure"),"orange",J.i18n.GT.$("Orange"),"orchid",J.i18n.GT.$("Orchid"),"showOrient",J.i18n.GT.$("Orientation"),"palindrome",J.i18n.GT.$("Palindrome"),"partialcharge",J.i18n.GT.$("Partial Charge"),"pause",J.i18n.GT.$("Pause"),"perspectiveDepthCB",J.i18n.GT.$("Perspective Depth"),"byPixelMenu",J.i18n.GT.$("Pixel Width"),"onceThrough",J.i18n.GT.$("Play Once"),"play",J.i18n.GT.$("Play"),"polar",J.i18n.GT.$("Polar Residues"),"polymersText",J.i18n.GT.$("polymers: {0}"),
"labelPositionMenu",J.i18n.GT.$("Position Label on Atom"),"prevframe",J.i18n.GT.$("Previous Frame"),"PDBproteinMenu",J.i18n.GT.$("Protein"),"colorrasmolCB",J.i18n.GT.$("RasMol Colors"),"red",J.i18n.GT.$("Red"),"stereoRedBlue",J.i18n.GT.$("Red+Blue glasses"),"stereoRedCyan",J.i18n.GT.$("Red+Cyan glasses"),"stereoRedGreen",J.i18n.GT.$("Red+Green glasses"),"SIGNEDJAVAcaptureOn",J.i18n.GT.$("Re-enable capturing"),"FILEUNITninePoly",J.i18n.GT.$("Reload + Polyhedra"),"reload",J.i18n.GT.$("Reload"),"restart",
J.i18n.GT.$("Restart"),"resume",J.i18n.GT.$("Resume"),"playrev",J.i18n.GT.$("Reverse"),"rewind",J.i18n.GT.$("Rewind"),"ribbons",J.i18n.GT.$("Ribbons"),"[color_ribbon]sMenu",null,"right",J.i18n.GT.$("Right"),"RNA",J.i18n.GT.$("RNA"),"rockets",J.i18n.GT.$("Rockets"),"[color_rockets]Menu",null,"salmon",J.i18n.GT.$("Salmon"),"writeFileTextVARIABLE",J.i18n.GT.$("Save a copy of {0}"),"SIGNEDwriteJmol",J.i18n.GT.$("Save as PNG/JMOL (image+zip)"),"SIGNEDwriteIsosurface",J.i18n.GT.$("Save JVXL isosurface"),
"writeHistory",J.i18n.GT.$("Save script with history"),"writeState",J.i18n.GT.$("Save script with state"),"saveMenu",J.i18n.GT.$("Save"),"sceneComputedMenu",J.i18n.GT.$("Scenes"),"renderSchemeMenu",J.i18n.GT.$("Scheme"),"aaStructureMenu",J.i18n.GT.$("Secondary Structure"),"structure#PDB",null,"selectMenuText",J.i18n.GT.$("Select ({0})"),"pickAtom",J.i18n.GT.$("Select atom"),"PDBpickChain",J.i18n.GT.$("Select chain"),"pickElement",J.i18n.GT.$("Select element"),"PDBpickGroup",J.i18n.GT.$("Select group"),
"pickMolecule",J.i18n.GT.$("Select molecule"),"SYMMETRYpickSite",J.i18n.GT.$("Select site"),"showSelectionsCB",J.i18n.GT.$("Selection Halos"),"SIGNEDJAVAcaptureFpsSPECIAL",J.i18n.GT.$("Set capture replay rate"),"[set_spin_FPS]Menu",J.i18n.GT.$("Set FPS"),"FRAMESanimFpsMenu",null,"PDBhbondBackbone",J.i18n.GT.$("Set H-Bonds Backbone"),"PDBhbondSidechain",J.i18n.GT.$("Set H-Bonds Side Chain"),"pickingMenu",J.i18n.GT.$("Set picking"),"PDBssbondBackbone",J.i18n.GT.$("Set SS-Bonds Backbone"),"PDBssbondSidechain",
J.i18n.GT.$("Set SS-Bonds Side Chain"),"[set_spin_X]Menu",J.i18n.GT.$("Set X Rate"),"[set_spin_Y]Menu",J.i18n.GT.$("Set Y Rate"),"[set_spin_Z]Menu",J.i18n.GT.$("Set Z Rate"),"shapely#PDB",J.i18n.GT.$("Shapely"),"showHydrogensCB",J.i18n.GT.$("Show Hydrogens"),"showMeasurementsCB",J.i18n.GT.$("Show Measurements"),"SYMMETRYpickSymmetry",J.i18n.GT.$("Show symmetry operation"),"showMenu",J.i18n.GT.$("Show"),"proteinSideChains",J.i18n.GT.$("Side Chains"),"slateblue",J.i18n.GT.$("Slate Blue"),"SYMMETRYShowComputedMenu",
J.i18n.GT.$("Space Group"),"showSpacegroup",null,"spectraMenu",J.i18n.GT.$("Spectra"),"spinMenu",J.i18n.GT.$("Spin"),"pickSpin",null,"SIGNEDJAVAcaptureBegin",J.i18n.GT.$("Start capturing"),"stereoMenu",J.i18n.GT.$("Stereographic"),"renderSticks",J.i18n.GT.$("Sticks"),"stop",J.i18n.GT.$("Stop"),"strands",J.i18n.GT.$("Strands"),"[color_strands]Menu",null,"PDBstructureMenu",J.i18n.GT.$("Structures"),"colorPDBStructuresMenu",null,"renderMenu",J.i18n.GT.$("Style"),"[color_isosurface]Menu",J.i18n.GT.$("Surfaces"),
"surfaceMenu",null,"SYMMETRYSelectComputedMenu",J.i18n.GT.$("Symmetry"),"SYMMETRYshowSymmetry",null,"FILEUNITMenu",null,"ZystemMenu",J.i18n.GT.$("Zystem"),"relativeTemperature#BFACTORS",J.i18n.GT.$("Temperature (Relative)"),"fixedTemperature#BFACTORS",J.i18n.GT.$("Temperature (Fixed)"),"SIGNEDJAVAcaptureLoopingSPECIAL",J.i18n.GT.$("Toggle capture looping"),"top",JU.PT.split(J.i18n.GT.$('Top[as in "view from the top, from above" - (translators: remove this bracketed part]'),"[")[0],"PDBrenderTraceOnly",
J.i18n.GT.$("Trace"),"trace",null,"[color_trace]Menu",null,"translations",J.i18n.GT.$("Translations"),"noCharge",J.i18n.GT.$("Uncharged Residues"),"[color_UNITCELL]Menu",J.i18n.GT.$("Unit cell"),"UNITCELLshow",null,"[set_UNITCELL]Menu",null,"showUNITCELLCB",null,"labelUpperLeft",J.i18n.GT.$("Upper Left"),"labelUpperRight",J.i18n.GT.$("Upper Right"),"surfVDW",J.i18n.GT.$("van der Waals Surface"),"VIBRATIONvectorMenu",J.i18n.GT.$("Vectors"),"property_vxyz#VIBRATION",null,"[color_vectors]Menu",null,
"VIBRATIONMenu",J.i18n.GT.$("Vibration"),"viewMenuText",J.i18n.GT.$("View {0}"),"viewMenu",J.i18n.GT.$("View"),"violet",J.i18n.GT.$("Violet"),"stereoWallEyed",J.i18n.GT.$("Wall-eyed viewing"),"white",J.i18n.GT.$("White"),"renderWireframe",J.i18n.GT.$("Wireframe"),"labelName",J.i18n.GT.$("With Atom Name"),"labelNumber",J.i18n.GT.$("With Atom Number"),"labelSymbol",J.i18n.GT.$("With Element Symbol"),"yellow",J.i18n.GT.$("Yellow"),"zoomIn",J.i18n.GT.$("Zoom In"),"zoomOut",J.i18n.GT.$("Zoom Out"),"zoomMenu",
J.i18n.GT.$("Zoom"),"vector005",J.i18n.GT.o(h,"0.05"),"bond100",J.i18n.GT.o(h,"0.10"),"hbond100",null,"ssbond100",null,"vector01",null,"10a",null,"bond150",J.i18n.GT.o(h,"0.15"),"hbond150",null,"ssbond150",null,"bond200",J.i18n.GT.o(h,"0.20"),"hbond200",null,"ssbond200",null,"20a",null,"bond250",J.i18n.GT.o(h,"0.25"),"hbond250",null,"ssbond250",null,"25a",null,"bond300",J.i18n.GT.o(h,"0.30"),"hbond300",null,"ssbond300",null,"50a",J.i18n.GT.o(h,"0.50"),"100a",J.i18n.GT.o(h,"1.0"),"1p",J.i18n.GT.i(j,
1),"10p",J.i18n.GT.i(j,10),"3p",J.i18n.GT.i(j,3),"vector3",null,"5p",J.i18n.GT.i(j,5),"atom100",J.i18n.GT.i(c,100),"atom15",J.i18n.GT.i(c,15),"atom20",J.i18n.GT.i(c,20),"atom25",J.i18n.GT.i(c,25),"atom50",J.i18n.GT.i(c,50),"atom75",J.i18n.GT.i(c,75),"SIGNEDNOGLwriteIdtf",J.i18n.GT.o(e,"IDTF"),"SIGNEDNOGLwriteMaya",J.i18n.GT.o(e,"Maya"),"SIGNEDNOGLwriteVrml",J.i18n.GT.o(e,"VRML"),"SIGNEDNOGLwriteX3d",J.i18n.GT.o(e,"X3D"),"SIGNEDNOGLwriteSTL",J.i18n.GT.o(e,"STL"),"SIGNEDNOGLwriteGif",J.i18n.GT.o(f,
"GIF"),"SIGNEDNOGLwriteJpg",J.i18n.GT.o(f,"JPG"),"SIGNEDNOGLwritePng",J.i18n.GT.o(f,"PNG"),"SIGNEDNOGLwritePngJmol",J.i18n.GT.o(f,"PNG+JMOL"),"SIGNEDNOGLwritePovray",J.i18n.GT.o(f,"POV-Ray"),"FILEUNITnineRestricted",J.i18n.GT.o(J.i18n.GT.$("Reload {0} + Display {1}"),b(-1,["{444 666 1}","555"])),"FILEMOLload",J.i18n.GT.o(d,"(molecular)"),"FILEUNITone",J.i18n.GT.o(d,"{1 1 1}"),"FILEUNITnine",J.i18n.GT.o(d,"{444 666 1}"),"vectorScale02",J.i18n.GT.o(g,"0.2"),"vectorScale05",J.i18n.GT.o(g,"0.5"),"vectorScale1",
J.i18n.GT.o(g,"1"),"vectorScale2",J.i18n.GT.o(g,"2"),"vectorScale5",J.i18n.GT.o(g,"5"),"surfSolvent14",J.i18n.GT.o(J.i18n.GT.$("Solvent Surface ({0}-Angstrom probe)"),"1.4"),"surfSolventAccessible14",J.i18n.GT.o(J.i18n.GT.$("Solvent-Accessible Surface (VDW + {0} Angstrom)"),"1.4"),"vibration20","*2","vibration05","/2","JAVAmemTotal","?","JAVAmemMax",null,"JAVAprocessors",null,"s0","0","animfps10","10","s10",null,"zoom100","100%","zoom150","150%","animfps20","20","s20",null,"zoom200","200%","animfps30",
"30","s30",null,"s40","40","zoom400","400%","animfps5","5","s5",null,"animfps50","50","s50",null,"zoom50","50%","zoom800","800%","JSConsole","JavaScript Console","jmolMenu","Jmol","date",JV.JC.date,"version",JV.JC.version,"javaVender",JV.Viewer.strJavaVendor,"javaVersion",JV.Viewer.strJavaVersion,"os",JV.Viewer.strOSName,"jmolorg","http://www.jmol.org"]);J.i18n.GT.setDoTranslate(a);a=1;for(e=c.length;a<e;a+=2)null==c[a]&&(c[a]=c[a-2]);return c});n(c$,"getMenuAsText",function(a){return this.getStuctureAsText(a,
J.popup.MainPopupResourceBundle.menuContents,J.popup.MainPopupResourceBundle.structureContents)},"~S");N(c$,"MENU_NAME","popupMenu");c$.menuContents=c$.prototype.menuContents=b(-1,[b(-1,["@COLOR","black darkgray lightgray white - red orange yellow green cyan blue indigo violet"]),b(-1,["@AXESCOLOR","gray salmon maroon olive slateblue gold orchid"]),b(-1,["popupMenu","fileMenu modelSetMenu FRAMESbyModelComputedMenu configurationComputedMenu - selectMenuText viewMenu renderMenu colorMenu - surfaceMenu FILEUNITMenu - sceneComputedMenu zoomMenu spinMenu VIBRATIONMenu spectraMenu FRAMESanimateMenu - measureMenu pickingMenu - showConsole JSConsole showMenu computationMenu - languageComputedMenu aboutMenu"]),
b(-1,["fileMenu","loadMenu saveMenu exportMenu SIGNEDJAVAcaptureMenuSPECIAL "]),b(-1,["loadMenu","SIGNEDloadFile SIGNEDloadUrl SIGNEDloadPdb SIGNEDloadScript - reload SIGNEDloadFileUnitCell"]),b(-1,["saveMenu","writeFileTextVARIABLE writeState writeHistory SIGNEDwriteJmol SIGNEDwriteIsosurface "]),b(-1,["exportMenu","SIGNEDNOGLwriteGif SIGNEDNOGLwriteJpg SIGNEDNOGLwritePng SIGNEDNOGLwritePngJmol SIGNEDNOGLwritePovray - SIGNEDNOGLwriteVrml SIGNEDNOGLwriteX3d SIGNEDNOGLwriteSTL"]),b(-1,["selectMenuText",
"hideNotSelectedCB showSelectionsCB - selectAll selectNone invertSelection - elementsComputedMenu SYMMETRYSelectComputedMenu - PDBproteinMenu PDBnucleicMenu PDBheteroMenu PDBcarboMenu PDBnoneOfTheAbove"]),b(-1,["PDBproteinMenu","PDBaaResiduesComputedMenu - allProtein proteinBackbone proteinSideChains - polar nonpolar - positiveCharge negativeCharge noCharge"]),b(-1,["PDBcarboMenu","PDBcarboResiduesComputedMenu - allCarbo"]),b(-1,["PDBnucleicMenu","PDBnucleicResiduesComputedMenu - allNucleic nucleicBackbone nucleicBases - DNA RNA - atPairs auPairs gcPairs - aaStructureMenu"]),
b(-1,["PDBheteroMenu","PDBheteroComputedMenu - allHetero Solvent Water - Ligand exceptWater nonWaterSolvent"]),b(-1,["viewMenu","best front left right top bottom back - axisX axisY axisZ - axisA axisB axisC"]),b(-1,["renderMenu","renderSchemeMenu - atomMenu labelMenu bondMenu hbondMenu ssbondMenu - PDBstructureMenu - [set_axes]Menu [set_boundbox]Menu [set_UNITCELL]Menu - perspectiveDepthCB stereoMenu"]),b(-1,["renderSchemeMenu","renderCpkSpacefill renderBallAndStick renderSticks renderWireframe PDBrenderCartoonsOnly PDBrenderTraceOnly"]),
b(-1,["atomMenu","showHydrogensCB - atomNone - atom15 atom20 atom25 atom50 atom75 atom100"]),b(-1,["bondMenu","bondNone bondWireframe - bond100 bond150 bond200 bond250 bond300"]),b(-1,["hbondMenu","hbondCalc hbondNone hbondWireframe - PDBhbondSidechain PDBhbondBackbone - hbond100 hbond150 hbond200 hbond250 hbond300"]),b(-1,["ssbondMenu","ssbondNone ssbondWireframe - PDBssbondSidechain PDBssbondBackbone - ssbond100 ssbond150 ssbond200 ssbond250 ssbond300"]),b(-1,["PDBstructureMenu","structureNone - backbone cartoon cartoonRockets ribbons rockets strands trace"]),
b(-1,["VIBRATIONvectorMenu","vectorOff vectorOn vibScale20 vibScale05 vector3 vector005 vector01 - vectorScale02 vectorScale05 vectorScale1 vectorScale2 vectorScale5"]),b(-1,["stereoMenu","stereoNone stereoRedCyan stereoRedBlue stereoRedGreen stereoCrossEyed stereoWallEyed"]),b(-1,["labelMenu","labelNone - labelSymbol labelName labelNumber - labelPositionMenu"]),b(-1,["labelPositionMenu","labelCentered labelUpperRight labelLowerRight labelUpperLeft labelLowerLeft"]),b(-1,["colorMenu","colorrasmolCB [color_]schemeMenu - [color_atoms]Menu [color_bonds]Menu [color_hbonds]Menu [color_ssbonds]Menu colorPDBStructuresMenu [color_isosurface]Menu - [color_labels]Menu [color_vectors]Menu - [color_axes]Menu [color_boundbox]Menu [color_UNITCELL]Menu [color_background]Menu"]),
b(-1,["[color_atoms]Menu","schemeMenu - @COLOR - opaque translucent"]),b(-1,["[color_bonds]Menu","none - @COLOR - opaque translucent"]),b(-1,["[color_hbonds]Menu",null]),b(-1,["[color_ssbonds]Menu",null]),b(-1,["[color_labels]Menu",null]),b(-1,["[color_vectors]Menu",null]),b(-1,["[color_backbone]Menu","none - schemeMenu - @COLOR - opaque translucent"]),b(-1,["[color_cartoon]sMenu",null]),b(-1,["[color_ribbon]sMenu",null]),b(-1,["[color_rockets]Menu",null]),b(-1,["[color_strands]Menu",null]),b(-1,
["[color_trace]Menu",null]),b(-1,["[color_background]Menu","@COLOR"]),b(-1,["[color_isosurface]Menu","@COLOR - opaque translucent"]),b(-1,["[color_axes]Menu","@AXESCOLOR"]),b(-1,["[color_boundbox]Menu",null]),b(-1,["[color_UNITCELL]Menu",null]),b(-1,["colorPDBStructuresMenu","[color_backbone]Menu [color_cartoon]sMenu [color_ribbon]sMenu [color_rockets]Menu [color_strands]Menu [color_trace]Menu"]),b(-1,["schemeMenu","cpk molecule formalcharge partialcharge - altloc#PDB amino#PDB chain#PDB group#PDB monomer#PDB shapely#PDB structure#PDB relativeTemperature#BFACTORS fixedTemperature#BFACTORS property_vxyz#VIBRATION"]),
b(-1,["[color_]schemeMenu",null]),b(-1,["zoomMenu","zoom50 zoom100 zoom150 zoom200 zoom400 zoom800 - zoomIn zoomOut"]),b(-1,["spinMenu","spinOn spinOff - [set_spin_X]Menu [set_spin_Y]Menu [set_spin_Z]Menu - [set_spin_FPS]Menu"]),b(-1,["VIBRATIONMenu","vibrationOff vibrationOn vibration20 vibration05 VIBRATIONvectorMenu"]),b(-1,["spectraMenu","hnmrMenu cnmrMenu"]),b(-1,["FRAMESanimateMenu","animModeMenu - play pause resume stop - nextframe prevframe rewind - playrev restart - FRAMESanimFpsMenu"]),
b(-1,["FRAMESanimFpsMenu","animfps5 animfps10 animfps20 animfps30 animfps50"]),b(-1,["measureMenu","showMeasurementsCB - measureOff measureDistance measureAngle measureTorsion PDBmeasureSequence - measureDelete measureList - distanceNanometers distanceAngstroms distancePicometers distanceHz"]),b(-1,["pickingMenu","pickOff pickCenter pickIdent pickLabel pickAtom pickMolecule pickElement - pickSpin - modelKitMode - PDBpickChain PDBpickGroup SYMMETRYpickSite"]),b(-1,["computationMenu","minimize modelkit"]),
b(-1,["showMenu","showHistory showFile showFileHeader - showOrient showMeasure - showSpacegroup showState SYMMETRYshowSymmetry UNITCELLshow - showIsosurface showMo - extractMOL"]),b(-1,["SIGNEDJAVAcaptureMenuSPECIAL","SIGNEDJAVAcaptureRock SIGNEDJAVAcaptureSpin - SIGNEDJAVAcaptureBegin SIGNEDJAVAcaptureEnd SIGNEDJAVAcaptureOff SIGNEDJAVAcaptureOn SIGNEDJAVAcaptureFpsSPECIAL SIGNEDJAVAcaptureLoopingSPECIAL"]),b(-1,["[set_spin_X]Menu","s0 s5 s10 s20 s30 s40 s50"]),b(-1,["[set_spin_Y]Menu",null]),b(-1,
["[set_spin_Z]Menu",null]),b(-1,["[set_spin_FPS]Menu",null]),b(-1,["animModeMenu","onceThrough palindrome loop"]),b(-1,["surfaceMenu","surfDots surfVDW surfSolventAccessible14 surfSolvent14 surfMolecular surf2MEP surfMEP surfMoComputedMenuText - surfOpaque surfTranslucent surfOff"]),b(-1,["FILEUNITMenu","SYMMETRYShowComputedMenu FILEMOLload FILEUNITone FILEUNITnine FILEUNITnineRestricted FILEUNITninePoly"]),b(-1,["[set_axes]Menu","on off#axes dotted - byPixelMenu byAngstromMenu"]),b(-1,["[set_boundbox]Menu",
null]),b(-1,["[set_UNITCELL]Menu",null]),b(-1,["byPixelMenu","1p 3p 5p 10p"]),b(-1,["byAngstromMenu","10a 20a 25a 50a 100a"]),b(-1,["aboutMenu","jmolMenu ZystemMenu"]),b(-1,["jmolMenu","APPLETid version date - help - mouse translations jmolorg"]),b(-1,["ZystemMenu","os javaVender javaVersion JAVAprocessors JAVAmemMax JAVAmemTotal"])]);c$.structureContents=c$.prototype.structureContents=b(-1,[b(-1,["jmolorg",'show url "http://www.jmol.org"']),b(-1,["help","help"]),b(-1,["mouse",'show url "http://wiki.jmol.org/index.php/Mouse_Manual"']),
b(-1,["translations",'show url "http://wiki.jmol.org/index.php/Internationalisation"']),b(-1,["colorrasmolCB",""]),b(-1,["hideNotSelectedCB","set hideNotSelected true | set hideNotSelected false; hide(none)"]),b(-1,["perspectiveDepthCB",""]),b(-1,["showAxesCB","set showAxes true | set showAxes false;set axesMolecular"]),b(-1,["showBoundBoxCB",""]),b(-1,["showHydrogensCB",""]),b(-1,["showMeasurementsCB",""]),b(-1,["showSelectionsCB",""]),b(-1,["showUNITCELLCB",""]),b(-1,["selectAll","SELECT all"]),
b(-1,["selectNone","SELECT none"]),b(-1,["invertSelection","SELECT not selected"]),b(-1,["allProtein","SELECT protein"]),b(-1,["proteinBackbone","SELECT protein and backbone"]),b(-1,["proteinSideChains","SELECT protein and not backbone"]),b(-1,["polar","SELECT protein and polar"]),b(-1,["nonpolar","SELECT protein and not polar"]),b(-1,["positiveCharge","SELECT protein and basic"]),b(-1,["negativeCharge","SELECT protein and acidic"]),b(-1,["noCharge","SELECT protein and not (acidic,basic)"]),b(-1,
["allCarbo","SELECT carbohydrate"]),b(-1,["allNucleic","SELECT nucleic"]),b(-1,["DNA","SELECT dna"]),b(-1,["RNA","SELECT rna"]),b(-1,["nucleicBackbone","SELECT nucleic and backbone"]),b(-1,["nucleicBases","SELECT nucleic and not backbone"]),b(-1,["atPairs","SELECT a,t"]),b(-1,["gcPairs","SELECT g,c"]),b(-1,["auPairs","SELECT a,u"]),b(-1,["A","SELECT a"]),b(-1,["C","SELECT c"]),b(-1,["G","SELECT g"]),b(-1,["T","SELECT t"]),b(-1,["U","SELECT u"]),b(-1,["allHetero","SELECT hetero"]),b(-1,["Solvent",
"SELECT solvent"]),b(-1,["Water","SELECT water"]),b(-1,["nonWaterSolvent","SELECT solvent and not water"]),b(-1,["exceptWater","SELECT hetero and not water"]),b(-1,["Ligand","SELECT ligand"]),b(-1,["PDBnoneOfTheAbove","SELECT not(hetero,protein,nucleic,carbohydrate)"]),b(-1,["best","rotate best -1.0"]),b(-1,["front",J.popup.MainPopupResourceBundle.Box("moveto 2.0 front;delay 1")]),b(-1,["left",J.popup.MainPopupResourceBundle.Box("moveto 1.0 front;moveto 2.0 left;delay 1")]),b(-1,["right",J.popup.MainPopupResourceBundle.Box("moveto 1.0 front;moveto 2.0 right;delay 1")]),
b(-1,["top",J.popup.MainPopupResourceBundle.Box("moveto 1.0 front;moveto 2.0 top;delay 1")]),b(-1,["bottom",J.popup.MainPopupResourceBundle.Box("moveto 1.0 front;moveto 2.0 bottom;delay 1")]),b(-1,["back",J.popup.MainPopupResourceBundle.Box("moveto 1.0 front;moveto 2.0 back;delay 1")]),b(-1,["axisA","moveto axis a"]),b(-1,["axisB","moveto axis b"]),b(-1,["axisC","moveto axis c"]),b(-1,["axisX","moveto axis x"]),b(-1,["axisY","moveto axis y"]),b(-1,["axisZ","moveto axis z"]),b(-1,["renderCpkSpacefill",
"restrict bonds not selected;select not selected;spacefill 100%;color cpk"]),b(-1,["renderBallAndStick","restrict bonds not selected;select not selected;spacefill 23%AUTO;wireframe 0.15;color cpk"]),b(-1,["renderSticks","restrict bonds not selected;select not selected;wireframe 0.3;color cpk"]),b(-1,["renderWireframe","restrict bonds not selected;select not selected;wireframe on;color cpk"]),b(-1,["PDBrenderCartoonsOnly","restrict bonds not selected;select not selected;cartoons on;color structure"]),
b(-1,["PDBrenderTraceOnly","restrict bonds not selected;select not selected;trace on;color structure"]),b(-1,["atomNone","cpk off"]),b(-1,["atom15","cpk 15%"]),b(-1,["atom20","cpk 20%"]),b(-1,["atom25","cpk 25%"]),b(-1,["atom50","cpk 50%"]),b(-1,["atom75","cpk 75%"]),b(-1,["atom100","cpk on"]),b(-1,["bondNone","wireframe off"]),b(-1,["bondWireframe","wireframe on"]),b(-1,["bond100","wireframe .1"]),b(-1,["bond150","wireframe .15"]),b(-1,["bond200","wireframe .2"]),b(-1,["bond250","wireframe .25"]),
b(-1,["bond300","wireframe .3"]),b(-1,["hbondCalc","hbonds calculate"]),b(-1,["hbondNone","hbonds off"]),b(-1,["hbondWireframe","hbonds on"]),b(-1,["PDBhbondSidechain","set hbonds sidechain"]),b(-1,["PDBhbondBackbone","set hbonds backbone"]),b(-1,["hbond100","hbonds .1"]),b(-1,["hbond150","hbonds .15"]),b(-1,["hbond200","hbonds .2"]),b(-1,["hbond250","hbonds .25"]),b(-1,["hbond300","hbonds .3"]),b(-1,["ssbondNone","ssbonds off"]),b(-1,["ssbondWireframe","ssbonds on"]),b(-1,["PDBssbondSidechain","set ssbonds sidechain"]),
b(-1,["PDBssbondBackbone","set ssbonds backbone"]),b(-1,["ssbond100","ssbonds .1"]),b(-1,["ssbond150","ssbonds .15"]),b(-1,["ssbond200","ssbonds .2"]),b(-1,["ssbond250","ssbonds .25"]),b(-1,["ssbond300","ssbonds .3"]),b(-1,["structureNone","backbone off;cartoons off;ribbons off;rockets off;strands off;trace off;"]),b(-1,["backbone","restrict not selected;select not selected;backbone 0.3"]),b(-1,["cartoon","restrict not selected;select not selected;set cartoonRockets false;cartoons on"]),b(-1,["cartoonRockets",
"restrict not selected;select not selected;set cartoonRockets;cartoons on"]),b(-1,["ribbons","restrict not selected;select not selected;ribbons on"]),b(-1,["rockets","restrict not selected;select not selected;rockets on"]),b(-1,["strands","restrict not selected;select not selected;strands on"]),b(-1,["trace","restrict not selected;select not selected;trace 0.3"]),b(-1,["vibrationOff","vibration off"]),b(-1,["vibrationOn","vibration on"]),b(-1,["vibration20","vibrationScale *= 2"]),b(-1,["vibration05",
"vibrationScale /= 2"]),b(-1,["vectorOff","vectors off"]),b(-1,["vectorOn","vectors on"]),b(-1,["vector3","vectors 3"]),b(-1,["vector005","vectors 0.05"]),b(-1,["vector01","vectors 0.1"]),b(-1,["vectorScale02","vector scale 0.2"]),b(-1,["vectorScale05","vector scale 0.5"]),b(-1,["vectorScale1","vector scale 1"]),b(-1,["vectorScale2","vector scale 2"]),b(-1,["vectorScale5","vector scale 5"]),b(-1,["stereoNone","stereo off"]),b(-1,["stereoRedCyan","stereo redcyan 3"]),b(-1,["stereoRedBlue","stereo redblue 3"]),
b(-1,["stereoRedGreen","stereo redgreen 3"]),b(-1,["stereoCrossEyed","stereo -5"]),b(-1,["stereoWallEyed","stereo 5"]),b(-1,["labelNone","label off"]),b(-1,["labelSymbol","label %e"]),b(-1,["labelName","label %a"]),b(-1,["labelNumber","label %i"]),b(-1,["labelCentered","set labeloffset 0 0"]),b(-1,["labelUpperRight","set labeloffset 4 4"]),b(-1,["labelLowerRight","set labeloffset 4 -4"]),b(-1,["labelUpperLeft","set labeloffset -4 4"]),b(-1,["labelLowerLeft","set labeloffset -4 -4"]),b(-1,["zoom50",
"zoom 50"]),b(-1,["zoom100","zoom 100"]),b(-1,["zoom150","zoom 150"]),b(-1,["zoom200","zoom 200"]),b(-1,["zoom400","zoom 400"]),b(-1,["zoom800","zoom 800"]),b(-1,["zoomIn","move 0 0 0 40 0 0 0 0 1"]),b(-1,["zoomOut","move 0 0 0 -40 0 0 0 0 1"]),b(-1,["spinOn","spin on"]),b(-1,["spinOff","spin off"]),b(-1,["s0","0"]),b(-1,["s5","5"]),b(-1,["s10","10"]),b(-1,["s20","20"]),b(-1,["s30","30"]),b(-1,["s40","40"]),b(-1,["s50","50"]),b(-1,["onceThrough","anim mode once#"]),b(-1,["palindrome","anim mode palindrome#"]),
b(-1,["loop","anim mode loop#"]),b(-1,["play","anim play#"]),b(-1,["pause","anim pause#"]),b(-1,["resume","anim resume#"]),b(-1,["stop","anim off#"]),b(-1,["nextframe","frame next#"]),b(-1,["prevframe","frame prev#"]),b(-1,["playrev","anim playrev#"]),b(-1,["rewind","anim rewind#"]),b(-1,["restart","anim on#"]),b(-1,["animfps5","anim fps 5#"]),b(-1,["animfps10","anim fps 10#"]),b(-1,["animfps20","anim fps 20#"]),b(-1,["animfps30","anim fps 30#"]),b(-1,["animfps50","anim fps 50#"]),b(-1,["measureOff",
"set pickingstyle MEASURE OFF; set picking OFF"]),b(-1,["measureDistance","set pickingstyle MEASURE; set picking MEASURE DISTANCE"]),b(-1,["measureAngle","set pickingstyle MEASURE; set picking MEASURE ANGLE"]),b(-1,["measureTorsion","set pickingstyle MEASURE; set picking MEASURE TORSION"]),b(-1,["PDBmeasureSequence","set pickingstyle MEASURE; set picking MEASURE SEQUENCE"]),b(-1,["measureDelete","measure delete"]),b(-1,["measureList","console on;show measurements"]),b(-1,["distanceNanometers","select *; set measure nanometers"]),
b(-1,["distanceAngstroms","select *; set measure angstroms"]),b(-1,["distancePicometers","select *; set measure picometers"]),b(-1,["distanceHz","select *; set measure hz"]),b(-1,["pickOff","set picking off"]),b(-1,["pickCenter","set picking center"]),b(-1,["pickIdent","set picking ident"]),b(-1,["pickLabel","set picking label"]),b(-1,["pickAtom","set picking atom"]),b(-1,["PDBpickChain","set picking chain"]),b(-1,["pickElement","set picking element"]),b(-1,["modelKitMode","set modelKitMode"]),b(-1,
["PDBpickGroup","set picking group"]),b(-1,["pickMolecule","set picking molecule"]),b(-1,["SYMMETRYpickSite","set picking site"]),b(-1,["pickSpin","set picking spin"]),b(-1,["SYMMETRYpickSymmetry","set picking symmetry"]),b(-1,["showConsole","console"]),b(-1,["JSConsole","JSCONSOLE"]),b(-1,["showFile","console on;show file"]),b(-1,["showFileHeader","console on;getProperty FileHeader"]),b(-1,["showHistory","console on;show history"]),b(-1,["showIsosurface","console on;show isosurface"]),b(-1,["showMeasure",
"console on;show measure"]),b(-1,["showMo","console on;show mo"]),b(-1,["showModel","console on;show model"]),b(-1,["showOrient","console on;show orientation"]),b(-1,["showSpacegroup","console on;show spacegroup"]),b(-1,["showState","console on;show state"]),b(-1,["reload",'load ""']),b(-1,["SIGNEDloadPdb","load ?PdbId?"]),b(-1,["SIGNEDloadFile","load ?"]),b(-1,["SIGNEDloadUrl","load http://?"]),b(-1,["SIGNEDloadFileUnitCell","load ? {1 1 1}"]),b(-1,["SIGNEDloadScript","script ?.spt"]),b(-1,["SIGNEDJAVAcaptureRock",
"animation mode loop;capture '?Jmol.gif' rock y 10"]),b(-1,["SIGNEDJAVAcaptureSpin","animation mode loop;capture '?Jmol.gif' spin y"]),b(-1,["SIGNEDJAVAcaptureBegin","capture '?Jmol.gif'"]),b(-1,["SIGNEDJAVAcaptureEnd","capture ''"]),b(-1,["SIGNEDJAVAcaptureOff","capture off"]),b(-1,["SIGNEDJAVAcaptureOn","capture on"]),b(-1,["SIGNEDJAVAcaptureFpsSPECIAL","animation fps @{0+prompt('Capture replay frames per second?', animationFPS)};prompt 'animation FPS ' + animationFPS"]),b(-1,["SIGNEDJAVAcaptureLoopingSPECIAL",
"animation mode @{(animationMode=='ONCE' ? 'LOOP':'ONCE')};prompt 'animation MODE ' + animationMode"]),b(-1,["writeFileTextVARIABLE",'if (_applet && !_signedApplet) { console;show file } else { write file "?FILE?"}']),b(-1,["writeState",'if (_applet && !_signedApplet) { console;show state } else { write state "?FILEROOT?.spt"}']),b(-1,["writeHistory",'if (_applet && !_signedApplet) { console;show history } else { write history "?FILEROOT?.his"}']),b(-1,["SIGNEDwriteJmol",'write PNGJ "?FILEROOT?.png"']),
b(-1,["SIGNEDwriteIsosurface",'write isosurface "?FILEROOT?.jvxl"']),b(-1,["SIGNEDNOGLwriteGif",'write image "?FILEROOT?.gif"']),b(-1,["SIGNEDNOGLwriteJpg",'write image "?FILEROOT?.jpg"']),b(-1,["SIGNEDNOGLwritePng",'write image "?FILEROOT?.png"']),b(-1,["SIGNEDNOGLwritePngJmol",'write PNGJ "?FILEROOT?.png"']),b(-1,["SIGNEDNOGLwritePovray",'write POVRAY "?FILEROOT?.pov"']),b(-1,["SIGNEDNOGLwriteVrml",'write VRML "?FILEROOT?.wrl"']),b(-1,["SIGNEDNOGLwriteX3d",'write X3D "?FILEROOT?.x3d"']),b(-1,["SIGNEDNOGLwriteSTL",
'write STL "?FILEROOT?.stl"']),b(-1,["SIGNEDNOGLwriteIdtf",'write IDTF "?FILEROOT?.idtf"']),b(-1,["SIGNEDNOGLwriteMaya",'write MAYA "?FILEROOT?.ma"']),b(-1,["SYMMETRYshowSymmetry","console on;show symmetry"]),b(-1,["UNITCELLshow","console on;show unitcell"]),b(-1,["extractMOL",'console on;getproperty extractModel "visible" ']),b(-1,["minimize","minimize"]),b(-1,["modelkit","set modelkitmode"]),b(-1,["surfDots","dots on"]),b(-1,["surfVDW","isosurface delete resolution 0 solvent 0 translucent"]),b(-1,
["surfMolecular","isosurface delete resolution 0 molecular translucent"]),b(-1,["surfSolvent14","isosurface delete resolution 0 solvent 1.4 translucent"]),b(-1,["surfSolventAccessible14","isosurface delete resolution 0 sasurface 1.4 translucent"]),b(-1,["surfMEP","isosurface delete resolution 0 vdw color range all map MEP translucent"]),b(-1,["surf2MEP","isosurface delete resolution 0 vdw color range -0.1 0.1 map MEP translucent"]),b(-1,["surfOpaque","mo opaque;isosurface opaque"]),b(-1,["surfTranslucent",
"mo translucent;isosurface translucent"]),b(-1,["surfOff","mo delete;isosurface delete;var ~~sel = {selected};select *;dots off;select ~~sel"]),b(-1,["FILEMOLload",'save orientation;load "";restore orientation;center']),b(-1,["FILEUNITone",'save orientation;load "" {1 1 1} ;restore orientation;center']),b(-1,["FILEUNITnine",'save orientation;load "" {444 666 1} ;restore orientation;center']),b(-1,["FILEUNITnineRestricted",'save orientation;load "" {444 666 1} ;restore orientation; unitcell on; display cell=555;center visible;zoom 200']),
b(-1,["FILEUNITninePoly",'save orientation;load "" {444 666 1} ;restore orientation; unitcell on; display cell=555; polyhedra 4,6 (displayed);center (visible);zoom 200']),b(-1,["1p","on"]),b(-1,["3p","3"]),b(-1,["5p","5"]),b(-1,["10p","10"]),b(-1,["10a","0.1"]),b(-1,["20a","0.20"]),b(-1,["25a","0.25"]),b(-1,["50a","0.50"]),b(-1,["100a","1.0"])])});r("J.popup");fa(J.popup,"PopupHelper");r("J.popup");s(null,"J.popup.PopupResource",["java.io.BufferedReader","$.StringReader","java.util.Properties","JU.SB"],
function(){c$=x(function(){this.words=this.structure=null;w(this,arguments)},J.popup,"PopupResource");C(c$,function(a,b){this.structure=new java.util.Properties;this.words=new java.util.Properties;this.buildStructure(a);this.localize(null!=a,b)},"~S,java.util.Properties");j(c$,"getStructure",function(a){return this.structure.getProperty(a)},"~S");j(c$,"getWord",function(a){var b=this.words.getProperty(a);return null==b?a:b},"~S");j(c$,"setStructure",function(a,b){var e=new java.io.BufferedReader(new java.io.StringReader(a)),
f,d;try{for(;null!=(f=e.readLine());)if(!(0==f.length||"#"==f.charAt(0))){d=f.indexOf("=");0>d&&(d=f.length,f+="=");var g=f.substring(0,d).trim(),h=f.substring(d+1).trim(),j=null;if(0<=(d=g.indexOf("|")))j=g.substring(d+1).trim(),g=g.substring(0,d).trim();0!=g.length&&(0<h.length&&this.structure.setProperty(g,h),null!=j&&0<j.length&&this.words.setProperty(g,null==b?j:b.translate(j)))}}catch(k){if(!D(k,Exception))throw k;}try{e.close()}catch(l){if(!D(l,Exception))throw l;}},"~S,J.api.Translator");
j(c$,"addItems",function(a){for(var b="",e=0;e<a.length;e++){var f=a[e],d=f[1];null==d&&(d=b);b=d;this.structure.setProperty(f[0],d)}},"~A");j(c$,"localize",function(a,b){for(var e=this.getWordContents(),f=0;f<e.length;f++){var d=e[f++],g=this.words.getProperty(d);null==g&&(g=e[f]);this.words.setProperty(d,g);null!=b&&0<=d.indexOf("Text")&&b.setProperty(d,g)}},"~B,java.util.Properties");j(c$,"getStuctureAsText",function(a,b,e){return"# "+this.getMenuName()+".mnu "+a+"\n\n# Part I -- Menu Structure\n# ------------------------\n\n"+
this.dumpStructure(b)+"\n\n# Part II -- Key Definitions\n# --------------------------\n\n"+this.dumpStructure(e)+"\n\n# Part III -- Word Translations\n# -----------------------------\n\n"+this.dumpWords()},"~S,~A,~A");j(c$,"dumpWords",function(){for(var a=this.getWordContents(),b=new JU.SB,e=0;e<a.length;e++){var f=a[e++];null==this.structure.getProperty(f)&&b.append(f).append(" | ").append(a[e]).appendC("\n")}return b.toString()});j(c$,"dumpStructure",function(a){for(var b="",e=new JU.SB,f=0;f<a.length;f++){var d=
a[f][0],g=this.words.getProperty(d);null!=g&&(d+=" | "+g);e.append(d).append(" = ").append(null==a[f][1]?b:b=a[f][1]).appendC("\n")}return e.toString()},"~A")});r("J.awtjs2d");s(["J.popup.JmolPopup"],"J.awtjs2d.JSJmolPopup",["J.awtjs2d.JSPopupHelper"],function(){c$=O(J.awtjs2d,"JSJmolPopup",J.popup.JmolPopup);C(c$,function(){ea(this,J.awtjs2d.JSJmolPopup,[]);this.helper=new J.awtjs2d.JSPopupHelper(this)});n(c$,"menuShowPopup",function(a,b,e){try{a.show(this.isTainted?this.vwr.html5Applet:null,b,e)}catch(f){if(!D(f,
Exception))throw f;}this.isTainted=!1},"J.api.SC,~N,~N");n(c$,"getUnknownCheckBoxScriptToRun",function(){return null},"J.api.SC,~S,~S,~B");n(c$,"getImageIcon",function(){return null},"~S");n(c$,"menuFocusCallback",function(){},"~S,~S,~B")});r("J.awtjs2d");s(["J.popup.PopupHelper"],"J.awtjs2d.JSPopupHelper","JS.ButtonGroup $.JCheckBoxMenuItem $.JMenu $.JMenuItem $.JPopupMenu $.JRadioButtonMenuItem".split(" "),function(){c$=x(function(){this.buttonGroup=this.popup=null;w(this,arguments)},J.awtjs2d,
"JSPopupHelper",null,J.popup.PopupHelper);C(c$,function(a){this.popup=a},"J.popup.GenericPopup");n(c$,"menuCreatePopup",function(a,b){var e=new JS.JPopupMenu(a);e.setInvoker(b);return e},"~S,~O");n(c$,"getMenu",function(a){var b=new JS.JMenu;b.setName(a);return b},"~S");n(c$,"getMenuItem",function(a){return new JS.JMenuItem(a)},"~S");n(c$,"getRadio",function(){return new JS.JRadioButtonMenuItem},"~S");n(c$,"getCheckBox",function(){return new JS.JCheckBoxMenuItem},"~S");n(c$,"menuAddButtonGroup",function(a){null==
a?this.buttonGroup=null:(null==this.buttonGroup&&(this.buttonGroup=new JS.ButtonGroup),this.buttonGroup.add(a))},"J.api.SC");n(c$,"getItemType",function(a){return a.btnType},"J.api.SC");n(c$,"menuInsertSubMenu",function(a,b){b.setParent(a)},"J.api.SC,J.api.SC,~N");n(c$,"getSwingComponent",function(a){return a},"~O");n(c$,"menuClearListeners",function(a){null!=a&&a.disposeMenu()},"J.api.SC");j(c$,"itemStateChanged",function(a){this.popup.menuCheckBoxCallback(a.getSource())},"java.awt.event.ItemEvent");
j(c$,"actionPerformed",function(a){this.popup.menuClickCallback(a.getSource(),a.getActionCommand())},"java.awt.event.ActionEvent");n(c$,"getButtonGroup",function(){return this.buttonGroup});j(c$,"handleEvent",function(a){var b=""+a.getID();"mouseenter"===b?this.mouseEntered(a):"mouseleave"===b&&this.mouseExited(a)},"java.awt.event.MouseEvent");j(c$,"mouseEntered",function(a){a=a.getSource();this.popup.menuFocusCallback(a.getName(),a.getActionCommand(),!0)},"java.awt.event.MouseEvent");j(c$,"mouseExited",
function(a){a=a.getSource();this.popup.menuFocusCallback(a.getName(),a.getActionCommand(),!1)},"java.awt.event.MouseEvent");n(c$,"dispose",function(a){this.menuClearListeners(a);this.popup=null},"J.api.SC")})})(Clazz,Clazz.getClassName,Clazz.newLongArray,Clazz.doubleToByte,Clazz.doubleToInt,Clazz.doubleToLong,Clazz.declarePackage,Clazz.instanceOf,Clazz.load,Clazz.instantialize,Clazz.decorateAsClass,Clazz.floatToInt,Clazz.floatToLong,Clazz.makeConstructor,Clazz.defineEnumConstant,Clazz.exceptionOf,
Clazz.newIntArray,Clazz.defineStatics,Clazz.newFloatArray,Clazz.declareType,Clazz.prepareFields,Clazz.superConstructor,Clazz.newByteArray,Clazz.declareInterface,Clazz.p0p,Clazz.pu$h,Clazz.newShortArray,Clazz.innerTypeInstance,Clazz.isClassDefined,Clazz.prepareCallback,Clazz.newArray,Clazz.castNullAs,Clazz.floatToShort,Clazz.superCall,Clazz.decorateAsType,Clazz.newBooleanArray,Clazz.newCharArray,Clazz.implementOf,Clazz.newDoubleArray,Clazz.overrideConstructor,Clazz.clone,Clazz.doubleToShort,Clazz.getInheritedLevel,
Clazz.getParamsType,Clazz.isAF,Clazz.isAB,Clazz.isAI,Clazz.isAS,Clazz.isASS,Clazz.isAP,Clazz.isAFloat,Clazz.isAII,Clazz.isAFF,Clazz.isAFFF,Clazz.tryToSearchAndExecute,Clazz.getStackTrace,Clazz.inheritArgs,Clazz.alert,Clazz.defineMethod,Clazz.overrideMethod,Clazz.declareAnonymous,Clazz.cloneFinals);
